\name{(INTRO.DISTR)}
\alias{(INTRO.DISTR)}
\title{DISTR}
\center{S4 Classes for Distributions}
\synopsis{}

\section{Usage}{
   library("distr") 
}


\description{
\pkg{``distr''} is a package for R from version 1.8.1 onwards that is distributed
under GPL license 2.0. Its own current version is 1.4.
It requires package \pkg{setRNG} by Paul Gilbert, \email{pgilbert@bank-banque-canada.ca},
to be installed from 

\url{http://cran.r-project.org/mirrors.html}

The aim of this package is to provide a conceptual treatment of random variables (r.v.'s) by means of S4 classes.
A mother class \code{Distribution} is introduced with slots for a parameter and ---most important---
for the four constitutive methods \code{r},  \code{d}, \code{p}, and \code{q} for simulation respectively for evaluation of
density / c.d.f.\ and quantile function of the corresponding distribution. All distributions of the \pkg{base} package for which corresponding
\code{r}-,  \code{d}-, \code{p}-, and \code{q}-functions exist (like normal, Poisson, etc.)
are implemented as subclasses of either \code{AbscontDistribution} or \code{DiscreteDistribution},
which themselves are again subclasses of \code{Distribution}. %\\

This approach seems very appealing to us from a conceptual viewpoint:

\emph{Just pass an object of some derived distribution class to a generic function as argument
and let the dispatching mechanism decide what to do on run-time.}

As an example, we may automatically generate new objects of these classes with corresponding
\code{r},  \code{d}, \code{p}, and \code{q}-slots for the laws of r.v.'s under standard mathematical
univariate transformations and under convolution of independent r.v.'s. For \code{Distribution} objects \code{X}
and \code{Y} expressions like
\code{3*X+sin(exp(-Y/4+3))} have their natural interpretation as corresponding image distributions. 

Additionally, we also provide classes for a standardized treatment of simulations (also under contaminations)
and evaluations of statistical procedures on such simulations.
A somewhat longer and more detailed manual can be obtained under

\url{http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/}

}
\keyword{}



\eof
\name{AbscontDistribution-class}
\docType{class}
\alias{AbscontDistribution-class}
\alias{initialize,AbscontDistribution-method}

\title{Class "AbscontDistribution"}
\description{The \code{AbscontDistribution}-class is the mother-class of the classes \code{Beta}, \code{Cauchy}, 
\code{Chisq}, \code{Exp}, \code{F}, \code{Gamma}, \code{Lnorm}, \code{Logis}, \code{Norm}, \code{T}, \code{Unif} and 
\code{Weibull}. Further absolutely continuous distributions can be defined either by declaration of
own random number generator, density, cumulative distribution and quantile functions, or as result of a 
convolution of two absolutely continuous distributions or by application of a mathematical operator to an absolutely
continuous distribution. An additional way is, to specify only the random number generator. The function \code{RtoDPQ} then 
approximates the three remaining slots d, p and q by random sampling.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("AbscontDistribution", r, d, p, q)}.
The result of this call is an absolutely continuous distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: the space of the image of this distribution which has dimension 1
    and the name "Real Space" }
    \item{\code{param}:}{Object of class \code{"Parameter"}: the parameter of this distribution, having only 
    the slot name "Parameter of an absolutely continuous distribution" }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers}
    \item{\code{d}:}{Object of class \code{"function"}: density function}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative distribution function}
    \item{\code{q}:}{Object of class \code{"function"}: quantile function}
  }
}
\section{Extends}{
Class \code{"UnivariateDistribution"}, directly. \cr
Class \code{"Distribution"}, by class \code{"UnivariateDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "AbscontDistribution")}: initialize method }
    \item{Math}{\code{signature(x = "AbscontDistribution")}: application of a mathematical function, e.g. \code{sin} or
    \code{exp} (does not work with \code{log}!), to this absolutely continouos distribution}
    \item{-}{\code{signature(e1 = "AbscontDistribution")}: application of `-' to this absolutely continuous distribution}
    \item{*}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}: multiplication of this absolutely continuous 
    distribution by an object of class `numeric'}
    \item{/}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}: division of this absolutely continuous 
    distribution by an object of class `numeric'}
    \item{+}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}: addition of this absolutely continuous 
    distribution to an object of class `numeric'}
    \item{-}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}: subtraction of an object of class `numeric' from
    this absolutely continuous distribution }
    \item{*}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}: multiplication of this absolutely continuous 
    distribution by an object of class `numeric'}
    \item{+}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}: addition of this absolutely continuous 
    distribution to an object of class `numeric'}
    \item{-}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}: subtraction of this absolutely continuous 
    distribution from an object of class `numeric'}
    \item{+}{\code{signature(e1 = "AbscontDistribution", e2 = "AbscontDistribution")}: Convolution of two absolutely
    continuous distributions. The slots p, d and q are approximated by grids.}
    \item{-}{\code{signature(e1 = "AbscontDistribution", e2 = "AbscontDistribution")}: Convolution of two absolutely
    continuous distributions. The slots p, d and q are approximated by grids.}
    \item{plot}{\code{signature(object = "AbscontDistribution")}: plots density, cumulative distribution and quantile 
    function }
  }
}


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Parameter-class}}
\code{\link{UnivariateDistribution-class}}
\code{\link{Beta-class}}
\code{\link{Cauchy-class}}
\code{\link{Chisq-class}}
\code{\link{Exp-class}}
\code{\link{Fd-class}}
\code{\link{Gamma-class}}
\code{\link{Lnorm-class}}
\code{\link{Logis-class}}
\code{\link{Norm-class}}
\code{\link{Td-class}}
\code{\link{Unif-class}}
\code{\link{Weibull-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Reals-class}}
\code{\link{RtoDPQ}}

}
\examples{
N = Norm() # N is a normal distribution with mean=0 and sd=1.
E = Exp() # E is an exponential distribution with rate=1.
A1 = E+1 # a new absolutely continuous distributions with exact slots d, p, q
A2 = A1*3 # a new absolutely continuous distributions with exact slots d, p, q
A3 = N*0.9 + E*0.1 # a new absolutely continuous distribution with approximated slots d, p, q
r(A3)(1) # one random number generated from this distribution, e.g. -0.7150937
d(A3)(0) # The (approximated) density for x=0 is 0.4379882.
p(A3)(0) # The (approximated) probability that x <= 0 is 0.4562021.
q(A3)(.1) # The (approximated) 10 percent quantile is 0.1.
}
\keyword{}

\eof
\name{Beta-class}
\docType{class}
\alias{Beta-class}
\alias{Beta}
\alias{initialize,Beta-method}
\title{Class "Beta"}
\description{
  The Beta distribution with parameters \code{shape1} \eqn{= a} and
  \code{shape2} \eqn{= b} has density
  \deqn{f(x)=\frac{\Gamma(a+b)}{\Gamma(a)\Gamma(b)}{x}^{a} {(1-x)}^{b}%
  }{Gamma(a+b)/(Gamma(a)Gamma(b))x^(a-1)(1-x)^(b-1)}
  for \eqn{a > 0}, \eqn{b > 0} and \eqn{0 \le x \le 1}{0 <= x <= 1}
  where the boundary values at \eqn{x=0} or \eqn{x=1} are defined as
  by continuity (as limits).

  C.f. \code{\link{rbeta}} 
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{Beta(shape1, shape2)}.
  This object is a beta distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}:
      The space of the image of this distribution has got dimension 1 and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"BetaParameter"}:
      the parameter of this distribution (shape1 and shape2), declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers (calls function rbeta)}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function (calls function dbeta)}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative function (calls function pbeta)}
    \item{\code{q}:}{Object of class \code{"function"}:
      inverse of the cumulative function (calls function qbeta)}
  }
}
\section{Extends}{
  Class \code{"AbscontDistribution"}, directly. \cr
  Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}. \cr
  Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Beta")}:
      initialize method}
    \item{shape1}{\code{signature(object = "Beta")}:
      returns the slot shape1 of the parameter of the distribution}
    \item{shape1<-}{\code{signature(object = "Beta")}:
      modifies the slot shape1 of the parameter of the distribution}
    \item{shape2}{\code{signature(object = "Beta")}:
      returns the slot shape2 of the parameter of the distribution}
    \item{shape2<-}{\code{signature(object = "Beta")}:
      modifies the slot shape2 of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
  \code{\link{BetaParameter-class}}
  \code{\link{AbscontDistribution-class}}
  \code{\link{Reals-class}}
  \code{\link{rbeta}}
}
\examples{
B <- Beta(shape1 = 1, shape2 = 1)
# B is a beta distribution with shape1 = 1 and shape2 = 1.
r(B)(1) # one random number generated from this distribution, e.g. 0.6979795
d(B)(1) # Density of this distribution is 1 for x=1.
p(B)(1) # Probability that x < 1 is 1.
q(B)(.1) # Probability that x < 0.1 is 0.1.
shape1(B) # shape1 of this distribution is 1.
shape1(B) <- 2 # shape1 of this distribution is now 2.
}
\keyword{}

\eof
\name{BetaParameter-class}
\docType{class}
\alias{BetaParameter-class}
\alias{initialize,BetaParameter-method}
\title{Class "BetaParameter"}
\description{
  The parameter of a beta distribution, used by \code{Beta-class}
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("BetaParameter", shape1, shape2)}.
  Usually an object of this class is not needed on its own, it is
  generated   automatically when an object of the class Beta
  is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{shape1}:}{Object of class \code{"numeric"}: the shape1 of a beta distribution }
    \item{\code{shape2}:}{Object of class \code{"numeric"}: the shape2 of a beta distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "BetaParameter")}:
      initialize method}
    \item{shape1}{\code{signature(object = "BetaParameter")}:
      returns the slot shape1 of the parameter of the distribution}
    \item{shape1<-}{\code{signature(object = "BetaParameter")}:
      modifies the slot shape1 of the parameter of the distribution}
    \item{shape2}{\code{signature(object = "BetaParameter")}:
      returns the slot shape2 of the parameter of the distribution}
    \item{shape2<-}{\code{signature(object = "BetaParameter")}:
      modifies the slot shape2 of the parameter of the distribution}
  }
}
\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
  \code{\link{Beta-class}}
  \code{\link{Parameter-class}}
}
\examples{
W <- new("BetaParameter", shape1 = 1, shape2 = 1)
shape2(W) # shape2 of this distribution is 1.
shape2(W) <- 2 # shape2 of this distribution is now 2.
}
\keyword{}

\eof
\name{Binom-class}
\docType{class}
\alias{Binom-class}
\alias{Binom}
\alias{initialize,Binom-method}

\title{Class "Binom" }
\description{The binomial distribution with \code{size} \eqn{= n}, by default \eqn{=1}, and
  \code{prob} \eqn{= p}, by default \eqn{=0.5}, has density
  \deqn{p(x) = {n \choose x} {p}^{x} {(1-p)}^{n-x}}{
    p(x) = choose(n,x) p^x (1-p)^(n-x)}
  for \eqn{x = 0, \ldots, n}.

  C.f.\code{\link{rbinom}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Binom(prob, size)}.
This object is a binomial distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}: The space of the image of this
     distribution has got dimension 1 and the name "Natural Space". }
    \item{\code{param}:}{Object of class \code{"BinomParameter"}: the parameter of this distribution (\code{prob}, \code{size}),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rbinom}) }
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dbinom}) }
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pbinom}) }
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qbinom}).
    The quantile is defined as the smallest value x such that F(x) >= p, where F is the cumulative function. }
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted) vector containing the support of the discrete
    density function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{+}{\code{signature(e1 = "Binom", e2 = "Binom")}: For two binomial distributions with equal probabilities
    the exact convolution formula is implemented thereby improving the general numerical approximation.}
    \item{initialize}{\code{signature(.Object = "Binom")}: initialize method }
    \item{prob}{\code{signature(object = "Binom")}: returns the slot \code{prob} of the parameter of the distribution }
    \item{prob<-}{\code{signature(object = "Binom")}: modifies the slot \code{prob} of the parameter of the distribution }
    \item{size}{\code{signature(object = "Binom")}: returns the slot \code{size} of the parameter of the distribution }
    \item{size<-}{\code{signature(object = "Binom")}: modifies the slot \code{size} of the parameter of the distribution }
  }
}


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{BinomParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
\code{\link{rbinom}}
}
\examples{
B=Binom(prob=0.5,size=1) # B is a binomial distribution with prob=0.5 and size=1.
r(B)(1) # # one random number generated from this distribution, e.g. 1
d(B)(1) # Density of this distribution is  0.5 for x=1.
p(B)(0.4) # Probability that x<0.4 is 0.5.
q(B)(.1) # x=0 is the smallest value x such that p(B)(x)>=0.1.
size(B) # size of this distribution is 1.
size(B)=2 # size of this distribution is now 2.
C=Binom(prob=0.5,size=1) # C is a binomial distribution with prob=0.5 and size=1.
D=Binom(prob=0.6,size=1) # D is a binomial distribution with prob=0.6 and size=1.
E=B+C # E is a binomial distribution with prob=0.5 and size=3.
F=B+D # F is an object of class DiscreteDistribution.
}
\keyword{}

\eof
\name{BinomParameter-class}
\docType{class}
\alias{BinomParameter-class}
\alias{initialize,BinomParameter-method}

\title{Class "BinomParameter"}
\description{ The parameter of a binomial distribution, used by Binom-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("BinomParameter", prob, size)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Binom
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{prob}:}{Object of class \code{"numeric"}: the probability of a binomial distribution }
    \item{\code{size}:}{Object of class \code{"numeric"}: the size of a binomial distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "BinomParameter")}: initialize method }
    \item{prob}{\code{signature(object = "BinomParameter")}: returns the slot \code{prob} of the parameter of the
    distribution }
    \item{prob<-}{\code{signature(object = "BinomParameter")}: modifies the slot \code{prob} of the parameter of the
    distribution }
    \item{size}{\code{signature(object = "BinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
    \item{size<-}{\code{signature(object = "BinomParameter")}: modifies the slot \code{size} of the parameter of the distribution}
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Binom-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("BinomParameter",prob=0.5,size=1)
size(W) # size of this distribution is 1.
size(W)=2 # size of this distribution is now 2.
}
\keyword{}

\eof
\name{Cauchy-class}
\docType{class}
\alias{Cauchy-class}
\alias{Cauchy}
\alias{initialize,Cauchy-method}

\title{Class "Cauchy"}
\description{  The Cauchy distribution with location \eqn{l}, by default \eqn{=0}, and scale \eqn{s} , by default \eqn{=1},has
  density
  \deqn{f(x) = \frac{1}{\pi s}
    \left( 1 + \left(\frac{x - l}{s}\right)^2 \right)^{-1}%
  }{f(x) = 1 / (pi s (1 + ((x-l)/s)^2))}
  for all \eqn{x}.
C.f. \code{\link{rcauchy}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Cauchy(location, scale)}.
This object is a Cauchy distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The domain of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"CauchyParameter"}: the parameter of this distribution (location and scale),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rcauchy})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dcauchy})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pcauchy})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qcauchy})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Cauchy")}: initialize method }
    \item{location}{\code{signature(object = "Cauchy")}: returns the slot \code{location} of the parameter of the distribution }
    \item{location<-}{\code{signature(object = "Cauchy")}: modifies the slot \code{location} of the parameter of the distribution }
    \item{scale}{\code{signature(object = "Cauchy")}: returns the slot \code{scale} of the parameter of the distribution }
    \item{scale<-}{\code{signature(object = "Cauchy")}: modifies the slot \code{scale} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{CauchyParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rcauchy}}





}
\examples{
C=Cauchy(location=1,scale=1) # C is a Cauchy distribution with location=1 and scale=1.
r(C)(1) # one random number generated from this distribution, e.g. 4.104603
d(C)(1) # Density of this distribution is 0.3183099 for x=1.
p(C)(1) # Probability that x<1 is 0.5.
q(C)(.1) # Probability that x<-2.077684 is 0.1.
location(C) # location of this distribution is 1.
location(C)=2 # location of this distribution is now 2.
}
\keyword{}

\eof
\name{CauchyParameter-class}
\docType{class}
\alias{CauchyParameter-class}
\alias{initialize,CauchyParameter-method}

\title{Class "CauchyParameter"}
\description{ The parameter of a Cauchy distribution, used by Cauchy-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("CauchyParameter", location, scale)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Cauchy
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{location}:}{Object of class \code{"numeric"}: the location of a Cauchy distribution }
    \item{\code{scale}:}{Object of class \code{"numeric"}: the scale of a Cauchy distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "CauchyParameter")}: initialize method }
    \item{scale}{\code{signature(object = "CauchyParameter")}: returns the slot \code{scale} of the parameter of the distribution}
    \item{scale<-}{\code{signature(object = "CauchyParameter")}: modifies the slot \code{scale} of the parameter of the
    distribution }
    \item{location}{\code{signature(object = "CauchyParameter")}: returns the slot \code{location} of the parameter of the
    distribution }
    \item{location<-}{\code{signature(object = "CauchyParameter")}: modifies the slot \code{location} of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Cauchy-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("CauchyParameter",location=1,scale=1)
location(W) # location of this distribution is 1.
location(W)=2 # location of this distribution is now 2.
}
\keyword{}

\eof
\name{Chisq-class}
\docType{class}
\alias{Chisq-class}
\alias{Chisq}
\alias{initialize,Chisq-method}
\title{Class "Chisq"}
\description{
  The chi-squared distribution with \code{df}\eqn{= n} degrees of
  freedom has density
  \deqn{f_n(x) = \frac{1}{{2}^{n/2} \Gamma (n/2)} {x}^{n/2-1} {e}^{-x/2}}{%
    f_n(x) = 1 / (2^(n/2) Gamma(n/2))  x^(n/2-1) e^(-x/2)}
  for \eqn{x > 0}.  The mean and variance are \eqn{n} and \eqn{2n}.

  The non-central chi-squared distribution with \code{df}\eqn{= n}
  degrees of freedom and non-centrality parameter \code{ncp}
  \eqn{= \lambda} has density
  \deqn{
    f(x) = e^{-\lambda / 2}
      \sum_{r=0}^\infty \frac{(\lambda/2)^r}{r!}\, f_{n + 2r}(x)}{%
    f(x) = exp(-lambda/2) SUM_{r=0}^infty ((lambda/2)^r / r!) dchisq(x, df + 2r)
  }
  for \eqn{x \ge 0}.  For integer \eqn{n}, this is the distribution of
  the sum of squares of \eqn{n} normals each with variance one,
  \eqn{\lambda} being the sum of squares of the normal means.
  
  C.f. \code{\link{rchisq}}
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{Chisq(df, ncp)}.
  This object is a chi-squared distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}:
      The space of the image of this distribution has got dimension 1 and the name "Real Space".}
    \item{\code{param}:}{Object of class \code{"ChisqParameter"}:
      the parameter of this distribution (df and ncp), declared at its instantiation}
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers (calls function rchisq)}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function (calls function dchisq)}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative function (calls function pchisq)}
    \item{\code{q}:}{Object of class \code{"function"}:
      inverse of the cumulative function (calls function qchisq)}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Chisq")}: initialize method }
    \item{df}{\code{signature(object = "Chisq")}:
      returns the slot df of the parameter of the distribution }
    \item{df<-}{\code{signature(object = "Chisq")}:
      modifies the slot df of the parameter of the distribution }
    \item{ncp}{\code{signature(object = "Chisq")}:
      returns the slot ncp of the parameter of the distribution }
    \item{ncp<-}{\code{signature(object = "Chisq")}:
      modifies the slot ncp of the parameter of the distribution }
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{
Warning: The code for pchisq and qchisq is unreliable for values of ncp above approximately 290. 
}
\seealso{
\code{\link{ChisqParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rchisq}}
}
\examples{
C <- Chisq(df = 1, ncp = 1) # C is a chi-squared distribution with df=1 and ncp=1.
r(C)(1) # one random number generated from this distribution, e.g. 0.2557184
d(C)(1) # Density of this distribution is 0.2264666 for x = 1.
p(C)(1) # Probability that x < 1 is 0.4772499.
q(C)(.1) # Probability that x < 0.04270125 is 0.1.
df(C) # df of this distribution is 1.
df(C) <- 2 # df of this distribution is now 2.
}
\keyword{}

\eof
\name{ChisqParameter-class}
\docType{class}
\alias{ChisqParameter-class}
\alias{initialize,ChisqParameter-method}

\title{Class "ChisqParameter"}
\description{ The parameter of a chi-squared distribution, used by Chisq-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("ChisqParameter", ncp, df)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Chisq
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{ncp}:}{Object of class \code{"numeric"}: the ncp of a chi-squared distribution }
    \item{\code{df}:}{Object of class \code{"numeric"}: the df of a chi-squared distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "ChisqParameter")}: initialize method }
    \item{df}{\code{signature(object = "ChisqParameter")}: returns the slot \code{df} of the parameter of the distribution }
    \item{df<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{df} of the parameter of the distribution }
    \item{ncp}{\code{signature(object = "ChisqParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
    \item{ncp<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Chisq-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("ChisqParameter",df=1,ncp=1)
ncp(W) # ncp of this distribution is 1.
ncp(W)=2 # ncp of this distribution is now 2.
}
\keyword{}

\eof
\name{Contsimulation-class}
\docType{class}
\alias{Contsimulation-class}
\alias{Contsimulation}
\alias{initialize,Contsimulation-method}

\title{Class "Contsimulation" }
\description{  In an object of type \code{Contsimulation} data can be simulated in any distribution and size. One part 
(usually the largest) of the random numbers stems from an ideal distribution, the rest is contaminated.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Contsimulation(filename, runs, samplesize, seed, distribution.id,
distribution.c, rate)}.
A \code{Contsimulation}-object includes a filename, the number of runs, the size of the sample, the seed, the distribution
of the ideal and the contaminated data and the contamination rate. The slot Data stays empty until the method simulate has
been used.}
\section{Slots}{
  \describe{
    \item{\code{ind}:}{Object of class \code{"vectororNULL"}: Indicator of the same length as the data; saves whether each
    element of the data vector is contaminated or not}
    \item{\code{Data.id}:}{Object of class \code{"vectororNULL"}: -- the ideal data }
    \item{\code{Data.c}:}{Object of class \code{"vectororNULL"}: -- the contaminated data }
    \item{\code{rate}:}{Object of class \code{"numeric"}: the contamination rate, so the probability for each random number
    to be contaminated }
    \item{\code{distribution.c}:}{Object of class \code{"UnivariateDistribution"}: the distribution of the ideal data }
    \item{\code{distribution.id}:}{Object of class \code{"UnivariateDistribution"}: the distribution of the contaminated
    data }
    \item{\code{seed}:}{Object of class \code{"list"}: the seed the simulation has been generated with }
    \item{\code{filename}:}{Object of class \code{"character"}: the filename the Contsimulation shall be saved }
    \item{\code{Data}:}{Object of class \code{"vectororNULL"}: the simulated data }
    \item{\code{runs}:}{Object of class \code{"numeric"}: the number of runs of the data }
    \item{\code{samplesize}:}{Object of class \code{"numeric"}: the size of the sample, so the dimension of the data }
  }
}

\section{Extends}{
Class \code{"Dataclass"}, directly.
}

\section{Methods}{
  \describe{
    \item{Data.c}{\code{signature(object = "Contsimulation")}: returns the contaminated data }
    \item{Data.id}{\code{signature(object = "Contsimulation")}: returns the ideal data }
    \item{Data<-}{\code{signature(object = "Contsimulation")}: ERROR: A modification of simulated data is not allowed. }
    \item{distribution.c}{\code{signature(object = "Contsimulation")}: returns the distribution of the contaminated data }
    \item{distribution.c<-}{\code{signature(object = "Contsimulation")}: changes the distribution of the contaminated data}
    \item{distribution.id}{\code{signature(object = "Contsimulation")}: returns the distribution of the ideal data }
    \item{distribution.id<-}{\code{signature(object = "Contsimulation")}: changes the distribution of the ideal data }
    \item{seed}{\code{signature(object = "Contsimulation")}: returns the seed }
    \item{seed<-}{\code{signature(object = "Contsimulation")}: changes the seed }
    \item{ind}{\code{signature(object = "Contsimulation")}: returns the indicator which saves which data is contaminated }
    \item{initialize}{\code{signature(.Object = "Contsimulation")}: initialize method }
    \item{rate}{\code{signature(object = "Contsimulation")}: returns the contamination rate }
    \item{rate<-}{\code{signature(object = "Contsimulation")}: changes the contamination rate }
    \item{runs<-}{\code{signature(object = "Contsimulation")}: changes the number of runs }
    \item{samplesize<-}{\code{signature(object = "Contsimulation")}: changes the size of the sample }
    \item{savedata}{\code{signature(object = "Contsimulation")}: saves the simulation in the directory of R }
    \item{simulate}{\code{signature(x = "Contsimulation")}: generates the random numbers for the simulation }
    \item{plot}{\code{signature(x = "Contsimulation")}: produces a plot of the real data matrix }
    \item{print}{\code{signature(x = "Contsimulation")}: returns filename, seed, number of runs, the size of the sample, 
    the rate and the distributions }
    \item{summary}{\code{signature(object = "Contsimulation")}: returns filename, seed, number of runs, the size of the
    sample, the rate and a statistical summary for each run of the real data}
  }
}

\note{ Changing distributions, seed, runs, samplesize or rate deletes possibly simulated data, as it would not fit to the
new parameters. }


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Dataclass-class}}
\code{\link{Simulation-class}}
\code{\link{savedata-methods}}
\code{\link{plot-methods}}
\code{\link{simulate-methods}}
\code{\link{summary-methods}}
}
\examples{
N <- Norm() # N is a standard normal distribution.
C <- Cauchy() # C is a Cauchy distribution
cs <- Contsimulation(filename = "csim",
                     runs = 10,
                     samplesize = 3,
                     seed = setRNG(),
                     distribution.id = N,
                     distribution.c = C,
                     rate = 0.1)
simulate(cs)
# Each of the 30 random numbers is ideal (N-distributed) with
# probability 0.9 and contaminated (C-distributed) with
# probability = 0.1
summary(cs)
Data(cs) # different data
savedata(cs) # saves the object in the working directory of R...
load("csim") # loads it again...
Data(cs) # ...without the data - use simulate to return it!
}
\keyword{}

\eof
\name{Data-methods}
\docType{methods}
\alias{Data-methods}
\alias{Data<--methods}
\alias{Data}
\alias{Data<-}
\alias{Data,Dataclass-method}
\alias{Data<-,Dataclass-method}
\alias{Data<-,Simulation-method}
\alias{Data<-,Contsimulation-method}
\title{ Methods for Function Data in Package `distr' }
\description{}
\section{Methods}{\describe{
\item{Data}{\code{signature(object = "Dataclass")}: returns the data }
\item{Data<-}{\code{signature(object = "Dataclass")}: changes the data (does not work with a simulation or a contsimulation
object) }
\item{Data<-}{\code{signature(object = "Simulation")}: ERROR: A change of the data is not allowed. }
\item{Data<-}{\code{signature(object = "Contsimulation")}: ERROR: A change of the data is not allowed. }
}}
\keyword{}

\eof
\name{Data.c-methods}
\docType{methods}
\alias{Data.c-methods}
\alias{Data.c}
\alias{Data.c,Contsimulation-method}
\title{ Methods for Function Data.c in Package `distr' }
\description{Data.c-methods}

\section{Methods}{\describe{
\item{Data.c}{\code{signature(object = "Dataclass")}: returns the
  contaminated data }
}}
\keyword{}

\eof
\name{Data.id-methods}
\docType{methods}
\alias{Data.id-methods}
\alias{Data.id}
\alias{Data.id,Contsimulation-method}
\title{ Methods for Function Data.id in Package `distr'}
\description{Data.id-methods}

\section{Methods}{\describe{

\item{Data.id}{\code{signature(object = "Contsimulation")}: returns the ideal data }
}}
\keyword{}

\eof
\name{Dataclass-class}
\docType{class}
\alias{Dataclass-class}
\alias{Dataclass}
\alias{initialize,Dataclass-method}
\title{Class "Dataclass" }
\description{
  In an object of type "Dataclass" data can be saved containing any
  number of runs in any dimension. All information about the data is
  stored in a unified way.
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{Dataclass(filename, Data)}. 
  A Dataclass-object includes, aside from the actual data, a filename
  and the number of runs and the size of the sample, which give the
  number of rows and columns of the data matrix.
}
\section{Slots}{
  \describe{
    \item{\code{filename}:}{
      Object of class \code{"character"}: the filename the data shall be saved}
    \item{\code{Data}:}{Object of class \code{"vectororNULL"}:
      the actual data, either of type "NULL" (means no data) or "vector"}
    \item{\code{runs}:}{Object of class \code{"numeric"}:
      the number of runs of the data}
    \item{\code{samplesize}:}{Object of class \code{"numeric"}:
      the size of the sample}
  }
}
\section{Methods}{
  \describe{
    \item{Data}{\code{signature(object = "Dataclass")}:
      returns the actual data}
    \item{Data<-}{\code{signature(object = "Dataclass")}:
      changes the data}
    \item{evaluate}{\code{signature(object = "Dataclass", estimator =
	"function")}:

      creates an object of type "Evaluation", see there for further information }
    \item{filename}{\code{signature(object = "Dataclass")}:
      returns the the filename}
    \item{filename<-}{\code{signature(object = "Dataclass")}:
      changes the the filename}
    \item{initialize}{\code{signature(.Object = "Dataclass")}:
      initialize method}
    \item{runs}{\code{signature(object = "Dataclass")}:
      returns the number of runs}
    \item{samplesize}{\code{signature(object = "Dataclass")}:
      returns the size of the sample}
    \item{savedata}{\code{signature(object = "Dataclass")}:
      saves the object in the directory of R and also a copy without data}
    \item{plot}{\code{signature(x = "Dataclass")}:
      produces a plot of the data matrix}
    \item{print}{\code{signature(x = "Dataclass")}:
      returns filename, number of runs and the size of the sample}
    \item{summary}{\code{signature(object = "Dataclass")}:
      returns the same information as print, moreover a statistical
      summary for each run}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\note{
  The saved Dataclass can be loaded with the usual load-command, the
  saved comment with the function cload.
}
\seealso{
\code{\link{Simulation-class}}
\code{\link{Contsimulation-class}}
\code{\link{Evaluation-class}}
\code{\link{plot-methods}} \cr
\code{\link{print-methods}}
\code{\link{summary-methods}}
\code{\link{load}}
\code{\link{cload}}
\code{\link{savedata-methods}}
}
\examples{
D <- Dataclass(Data = matrix(c(1,2,3,4,5,6),2),
               filename = "xyz.sav")
# A new object of type "Dataclass" is created.
savedata(D)
# creates a file called "xyz.sav" where the information is saved and a
# copy "xyz.sav.comment" without data
Data(D) <- matrix(c(11,12,13,14,15,16),2) # changes the data of D
cload("xyz.sav") # loads the object without data - it is called "D.comment"
D.comment
load("xyz.sav") # loads the original object "D"
Data(D) # the original data: matrix(c(1,2,3,4,5,6),2)
evaluate(object = D, estimator = mean) # returns the mean of each variable
}
\keyword{}

\eof
\name{Dirac-class}
\docType{class}
\alias{Dirac-class}
\alias{Dirac}
\alias{initialize,Dirac-method}

\title{Class "Dirac"  }
\description{ The Dirac distribution with location \eqn{l}, by default \eqn{=0}, has density
\eqn{d(x) = 1} for \eqn{x = l}, \eqn{0} else.
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Dirac(location)}.
This object is a \code{Dirac} distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}: The space of the image of this
     distribution has got dimension 1 and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"DiracParameter"}: the parameter of this distribution (location),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers }
    \item{\code{d}:}{Object of class \code{"function"}: density function }
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function }
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function }
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted) vector containing the support of the discrete
    density function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Dirac")}: initialize method }
    \item{location}{\code{signature(object = "Dirac")}: returns the slot \code{location} of the parameter of the distribution }
    \item{location<-}{\code{signature(object = "Dirac")}: modifies the slot \code{location} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{DiracParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
}
\examples{
D <- Dirac(location = 0) # D is a Dirac distribution with location=0.
r(D)(1)
# r(D)(1) generates a pseudo-random-number according to a Dirac
# distribution with location = 0,
# which of course will take 0 as value almost surely.
d(D)(0) # Density of this distribution is 1 for x = 0.
p(D)(1) # Probability that x < 1 is 1.
q(D)(.1) # q(D)(x) is always 0 (= location).
location(D) # location of this distribution is 0.
location(D) <- 2 # location of this distribution is now 2.
}
\keyword{}

\eof
\name{DiracParameter-class}
\docType{class}
\alias{DiracParameter-class}
\alias{initialize,DiracParameter-method}

\title{Class "DiracParameter"}
\description{ The parameter of a Dirac distribution, used by \code{Dirac}-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("DiracParameter", location)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class \code{Dirac}
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{location}:}{Object of class \code{"numeric"}: the location of a Dirac distribution }\cr
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "DiracParameter")}: initialize method }
    \item{location}{\code{signature(object = "DiracParameter")}: returns the slot location of the parameter of the
    distribution }
    \item{location<-}{\code{signature(object = "DiracParameter")}: modifies the slot location of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Dirac-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("DiracParameter",location=1)
location(W) # location of this distribution is 1.
location(W)=2 # location of this distribution is now 2.
}
\keyword{}

\eof
\name{DiscreteDistribution-class}
\docType{class}
\alias{DiscreteDistribution-class}
\alias{initialize,DiscreteDistribution-method}

\title{Class "DiscreteDistribution"}
\description{The \code{DiscreteDistribution}-class is the mother-class of the classes \code{Binom}, \code{Dirac},
\code{Geom}, \code{Hyper}, \code{Nbinom} and \code{Poisson}. Further discrete distributions can be defined either by 
declaration of own random number generator, density and cumulative distribution and quantile functions, or as result of a 
convolution of two discrete distributions or by application of a mathematical operator to a discrete distribution. An 
additional way is, to specify only the random number generator. The function \code{RtoDPQ.d} then approximates the three 
remaining slots \code{d}, \code{p} and \code{q} by random sampling.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("DiscreteDistribution", r, d, p, q)}.
The result of this call is a discrete distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: the space of the image of this distribution which has dimension 1
    and the name "Real Space" }
    \item{\code{param}:}{Object of class \code{"Parameter"}: the parameter of this distribution, having only the
    slot name "Parameter of a discrete distribution" }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers}
    \item{\code{d}:}{Object of class \code{"function"}: density/probability function}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative distribution function}
    \item{\code{q}:}{Object of class \code{"function"}: quantile function}
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted) vector containing the support of the discrete
    density function}
  }
}
\section{Extends}{
Class \code{"UnivariateDistribution"}, directly.\cr
Class \code{"Distribution"}, by class \code{"UnivariateDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "DiscreteDistribution")}: initialize method }
    \item{Math}{\code{signature(x = "DiscreteDistribution")}: application of a mathematical function, e.g. \code{sin} or
    \code{exp} (does not work with \code{log}!), to this discrete distribution}
    \item{-}{\code{signature(e1 = "DiscreteDistribution")}: application of `-' to this discrete distribution}
    \item{*}{\code{signature(e1 = "DiscreteDistribution", e2 = "numeric")}: multiplication of this discrete distribution
    by an object of class `numeric'}
    \item{/}{\code{signature(e1 = "DiscreteDistribution", e2 = "numeric")}: division of this discrete distribution
    by an object of class `numeric'}
    \item{+}{\code{signature(e1 = "DiscreteDistribution", e2 = "numeric")}: addition of this discrete distribution
    to an object of class `numeric'}
    \item{-}{\code{signature(e1 = "DiscreteDistribution", e2 = "numeric")}: subtraction of an object of class `numeric'
    from this discrete distribution }
    \item{*}{\code{signature(e1 = "numeric", e2 = "DiscreteDistribution")}: multiplication of this discrete distribution
    by an object of class `numeric'}
    \item{+}{\code{signature(e1 = "numeric", e2 = "DiscreteDistribution")}: addition of this discrete distribution
    to an object of class `numeric'}
    \item{-}{\code{signature(e1 = "numeric", e2 = "DiscreteDistribution")}: subtraction of this discrete distribution
    from an object of class `numeric'}
    \item{+}{\code{signature(e1 = "DiscreteDistribution", e2 = "DiscreteDistribution")}: Convolution of two discrete
    distributions. The slots p, d and q are approximated by grids.}
    \item{-}{\code{signature(e1 = "DiscreteDistribution", e2 = "DiscreteDistribution")}: Convolution of two discrete
    distributions. The slots p, d and q are approximated by grids.}
    \item{support}{\code{signature(object = "DiscreteDistribution")}: returns the support}
    \item{plot}{\code{signature(object = "DiscreteDistribution")}: plots density, cumulative distribution and quantile
    function }
  }
}


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\note{ Working with a computer, we use a finite interval as support which carries at least mass \eqn{1-TruncQuantile}. }

\seealso{
\code{\link{Parameter-class}}
\code{\link{UnivariateDistribution-class}}
\code{\link{Binom-class}}
\code{\link{Dirac-class}}
\code{\link{Geom-class}}
\code{\link{Hyper-class}}
\code{\link{Nbinom-class}}
\code{\link{Pois-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{RtoDPQ.d}}

}
\examples{
B = Binom(prob=0.1,size=10) # B is a Binomial distribution with prob=0.1 and size=10.
P = Pois(lambda=1) # P is a Poisson distribution with lambda=1.
D1 = B+1 # a new discrete distributions with exact slots d, p, q
D2 = D1*3 # a new discrete distributions with exact slots d, p, q
D3 = B+P # a new discrete distributions with approximated slots d, p, q
D4 = D1+P # a new discrete distributions with approximated slots d, p, q
support(D4) # the (approximated) support of this distribution is 1, 2, ..., 21
r(D4)(1) # one random number generated from this distribution, e.g. 4
d(D4)(1) # The (approximated) density for x=1 is 0.1282716.
p(D4)(1) # The (approximated) probability that x<=1 is 0.1282716.
q(D4)(.5) # The (approximated) 50 percent quantile is 3.
}
\keyword{}

\eof
\name{Distribution-class}
\docType{class}
\alias{Distribution-class}

\title{Class "Distribution"}
\description{ The \code{Distribution-class} is the mother-class of the class \code{UnivariateDistribution}.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("Distribution")}.
}

\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Parameter"}: the space of the image }
    \item{\code{param}:}{Object of class \code{"function"}: the parameter }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers}
    \item{\code{d}:}{Object of class \code{"function"}: density function}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative distribution function}
    \item{\code{q}:}{Object of class \code{"OptionalFunction"}: quantile function}
  }
}
}
\section{Methods}{
  \describe{
    \item{img}{\code{signature(object = "Distribution")}: returns the space of the image}
    \item{param}{\code{signature(object = "Distribution")}: returns the parameter}
    \item{r}{\code{signature(object = "Distribution")}: returns the random number generator }
    \item{d}{\code{signature(object = "Distribution")}: returns the density function }
    \item{p}{\code{signature(object = "Distribution")}: returns the cumulative distribution function }
    \item{q}{\code{signature(object = "Distribution")}: returns the quantile function}
  }
}


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{UnivariateDistribution-class}}
\code{\link{Parameter-class}}

}
\keyword{}

\eof
\name{EuclideanSpace-class}
\docType{class}
\alias{EuclideanSpace-class}
\alias{initialize,EuclideanSpace-method}

\title{Class "EuclideanSpace" }
\description{ The distribution-classes contain a slot where the sample space is stored. One typical sample space is the
Euclidean Space in dimension k. }
\section{Objects from the Class}{
Objects could theoretically be created by calls of the form \code{new("EuclideanSpace", dimension, name)}.
Usually an object of this class is not needed on its own. \code{EuclideanSpace} is the mother-class of the class 
\code{Reals}, which is generated automatically when a univariate absolutly continuous distribution is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{dimension}:}{Object of class \code{"numeric"}: the dimension of the space, by default = 1 }
    \item{\code{name}:}{Object of class \code{"character"}: the name of the space, by default = "Euclidean Space"}
  }
}
\section{Extends}{
Class \code{"rSpace"}, directly.
}

\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "EuclideanSpace")}: initialize method }
    \item{liesIn}{\code{signature(object = "EuclideanSpace", x = "numeric")}: Does a particular vector lie in this space or
    not?
 }
    \item{dimension}{\code{signature(object = "EuclideanSpace")}: returns the dimension of the space }
    \item{dimension<-}{\code{signature(object = "EuclideanSpace")}: modifies the dimension of the space }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{rSpace-class}}
\code{\link{Reals-class}}
\code{\link{Distribution-class}}
\code{\link{liesIn-methods}}
}

\examples{
E=new("EuclideanSpace",dimension=2)
dimension(E) # The dimension of this space is 2.
dimension(E)=3 # The dimension of this space is now 3.
liesIn(E,c(0,0,0)) # TRUE
liesIn(E,c(0,0)) # FALSE
}


\keyword{}

\eof
\name{Evaluation-class}
\docType{class}
\alias{Evaluation-class}
\alias{initialize,Evaluation-method}

\title{Class "Evaluation" }
\description{ When an estimator is used to data of the type "Dataclass" with the method evaluate, the result is an object
of class "Evaluation". }
\section{Objects from the Class}{
Objects could be created by calls of the form \code{new("Evaluation", name, filename, call.ev, result, estimator)}.
It does not seem to be very useful to generate a new object this way, however. Use "evaluate" with a Dataclass object!}
\section{Slots}{
  \describe{
    \item{\code{name}:}{Object of class \code{"character"}: the name of the Dataclass object, which was called by evaluate }
    \item{\code{filename}:}{Object of class \code{"character"}: the filename of the evaluated object }
    \item{\code{call.ev}:}{Object of class \code{"call.ev"} the call which created the object, 


      e.g. ``evaluate(Dataclassobject)'' }
    \item{\code{result}:}{Object of class \code{"vector"}: the result of the evaluation of the estimation on data }
    \item{\code{estimator}:}{Object of class \code{"OptionalFunction"}: estimation function used }
  }
}
\section{Methods}{
  \describe{
    \item{call.ev}{\code{signature(object = "Evaluation")}: returns the call which created the object }
    \item{estimator}{\code{signature(object = "Evaluation")}: returns the estimator }
    \item{filename}{\code{signature(object = "Evaluation")}: returns the filename }
    \item{initialize}{\code{signature(.Object = "Evaluation")}: initialize method }
    \item{name}{\code{signature(object = "Evaluation")}: returns the name of the data object }
    \item{result}{\code{signature(object = "Evaluation")}: returns the result }
    \item{plot}{\code{signature(object = "Evaluation")}: returns a boxplot of the result }
    \item{print}{\code{signature(object = "Evaluation")}: returns the name of the data object, its filename, the estimator used
    and the result }
    \item{savedata}{\code{signature(object = "Evaluation")}: saves the object in two files in the directory of R - one with
    data, one without as comment file (see example) }
    \item{summary}{\code{signature(object = "Evaluation")}: returns the name of the data object, its filename, the
    estimator used and a statistical summary of the result }
  }
}
\note{ The saved "evaluation" can be loaded with the usual load-command, the saved comment with the function cload. }

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Dataclass-class}}
\code{\link{Simulation-class}}
\code{\link{Contsimulation-class}}
\code{\link{load}}
\code{\link{cload}}
\code{\link{savedata-methods}}
\code{\link{plot-methods}}
\code{\link{simulate-methods}}
\code{\link{summary-methods}}
}
\examples{
N <- Norm() # N is a standard normal distribution.
C <- Cauchy() # C is a Cauchy distribution
cs <- Contsimulation(filename = "csim",
                     runs = 5,
                     samplesize=5000,
                     seed=setRNG(),
                     distribution.id = N,
                     distribution.c = C,
                     rate = 0.1)
simulate(cs)
# Each of the 25000 random numbers is ideal (N-distributed) with
# probability 0.9 and contaminated (C-distributed) with probability = 0.1
summary(cs)
ev1 <- evaluate(cs, mean) # estimates the data with mean
ev1 # bad results
ev2 <- evaluate(cs,median) # estimates the data with median
ev2 # better results because median is robust
savedata(ev1)
# saves the evaluation with result as "csim.mean" and without result as
# "csim.mean.comment" in the working directory # of R - "csim" is the
# filename of the Contsimulation object, mean the name of the estimator
rm(ev1)
cload("csim.mean")
# loads the evaluation without result - the object is called ev1.comment
ev1.comment
load("csim.mean") # loads the evaluation with result
ev1
}
\keyword{}

\eof
\name{Exp-class}
\docType{class}
\alias{Exp-class}
\alias{Exp}
\alias{initialize,Exp-method}
\title{Class "Exp"}
\description{
  The exponential distribution with rate \eqn{\lambda} has density
  \deqn{
    f(x) = \lambda {e}^{- \lambda x}}{
    f(x) = lambda e^(- lambda x)}
  for \eqn{x \ge 0}.

  C.f. \code{\link{rexp}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Exp(rate)}.
This object is a exponential distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}:
      The space of the image of this distribution has got dimension 1
      and the name "Real Space".}
    \item{\code{param}:}{Object of class \code{"ExpParameter"}:
      the parameter of this distribution (rate), declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers (calls function rexp)}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function (calls function dexp)}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative function (calls function pexp)}
    \item{\code{q}:}{Object of class \code{"function"}:
      inverse of the cumulative function (calls function qexp)}
  }
}
\section{Extends}{
  Class \code{"AbscontDistribution"}, directly.
  Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.
  Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Exp")}:
      initialize method}
    \item{rate}{\code{signature(object = "Exp")}:
      returns the slot rate of the parameter of the distribution}
    \item{rate<-}{\code{signature(object = "Exp")}:
      modifies the slot rate of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{ExpParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rexp}}
}
\examples{
E <- Exp(rate = 1) # E is a exp distribution with rate = 1.
r(E)(1) # one random number generated from this distribution, e.g. 0.4190765
d(E)(1) # Density of this distribution is 0.3678794 for x = 1.
p(E)(1) # Probability that x < 1 is 0.6321206.
q(E)(.1) # Probability that x < 0.1053605 is 0.1.
rate(E) # rate of this distribution is 1.
rate(E) <- 2 # rate of this distribution is now 2.
}
\keyword{}

\eof
\name{ExpParameter-class}
\docType{class}
\alias{ExpParameter-class}
\alias{initialize,ExpParameter-method}

\title{Class "ExpParameter"}
\description{ The parameter of an exponential distribution, used by Exp-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("ExpParameter", rate)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Exp
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{rate}:}{Object of class \code{"numeric"}: the rate of an exponential distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "ExpParameter")}: initialize method }
    \item{rate}{\code{signature(object = "ExpParameter")}: returns the slot \code{rate} of the parameter of the distribution }
    \item{rate<-}{\code{signature(object = "ExpParameter")}: modifies the slot \code{rate} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Exp-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("ExpParameter", rate=1)
rate(W) # rate of this distribution is 1.
rate(W)=2 # rate of this distribution is now 2.
}
\keyword{}

\eof
\name{FParameter-class}
\docType{class}
\alias{FParameter-class}
\alias{initialize,FParameter-method}
\title{Class "FParameter"}
\description{ The parameter of a F distribution, used by Fd-class}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("FParameter", df1, df2)}.
  Usually an object of this class is not needed on its own, it is
  generated automatically when an object of the class Fd is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{df1}:}{Object of class \code{"numeric"}: the df1 of a F distribution}
    \item{\code{df2}:}{Object of class \code{"numeric"}: the df2 of a F distribution}
    \item{\code{name}:}{Object of class \code{"character"}:
      a name / comment for the parameters}
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "FParameter")}: initialize method }
    \item{df1}{\code{signature(object = "FParameter")}:
      returns the slot df1 of the parameter of the distribution}
    \item{df1<-}{\code{signature(object = "FParameter")}:
      modifies the slot df1 of the parameter of the distribution}
    \item{df2}{\code{signature(object = "FParameter")}:
      returns the slot df2 of the parameter of the distribution}
    \item{df2<-}{\code{signature(object = "FParameter")}:
      modifies the slot df2 of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Fd-class}}
\code{\link{Parameter-class}}
}
\examples{
W <- new("FParameter", df1 = 1, df2 = 1)
df2(W) # df2 of this distribution is 1.
df2(W) <- 2 # df2 of this distribution is now 2.
}
\keyword{}

\eof
\name{Fd-class}
\docType{class}
\alias{Fd-class}
\alias{Fd}
\alias{initialize,Fd-method}

\title{Class "Fd"}
\description{   The F distribution with \code{df1 =} \eqn{n_1}{n1}, by default \code{= 1}, 
  and \code{df2 =} \eqn{n_2}{n2}, by default \code{= 1}, degrees of freedom has density
  \deqn{
    d(x) = \frac{\Gamma(n_1/2 + n_2/2)}{\Gamma(n_1/2)\Gamma(n_2/2)}
    \left(\frac{n_1}{n_2}\right)^{n_1/2} x^{n_1/2 -1}
    \left(1 + \frac{n_1 x}{n_2}\right)^{-(n_1 + n_2) / 2}%
  }{d(x) = Gamma((n1 + n2)/2) / (Gamma(n1/2) Gamma(n2/2))
    (n1/n2)^(n1/2) x^(n1/2 - 1)
    (1 + (n1/n2) x)^-(n1 + n2)/2}
  for \eqn{x > 0}.

  C.f. \code{\link{rf}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Fd(df1, df2)}.
This object is a F distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"FParameter"}: the parameter of this distribution (df1 and df2),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function rf)}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function df)}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function pf)}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function qf)}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly. \cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}. \cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Fd")}: initialize method }
    \item{df1}{\code{signature(object = "Fd")}: returns the slot \code{df1} of the parameter of the distribution }
    \item{df1<-}{\code{signature(object = "Fd")}: modifies the slot \code{df1} of the parameter of the distribution }
    \item{df2}{\code{signature(object = "Fd")}: returns the slot \code{df2} of the parameter of the distribution }
    \item{df2<-}{\code{signature(object = "Fd")}: modifies the slot \code{df2} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{It is the distribution of the ratio of the mean squares of n1 and n2 independent standard normals, and hence of the
ratio of two independent chi-squared variates each divided by its degrees of freedom. Since the ratio of a normal and the
root mean-square of m independent normals has a Student's \eqn{t_m} distribution, the square of a \eqn{t_m} variate has a F
distribution on 1 and m degrees of freedom. 

The non-central F distribution is again the ratio of mean squares of independent normals of unit variance, but those in the
numerator are allowed to have non-zero means and ncp is the sum of squares of the means. 
}

\seealso{
\code{\link{FParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rf}}
}
\examples{
F=Fd(df1=1,df2=1) # F is a F distribution with df=1 and df2=1.
r(F)(1) # one random number generated from this distribution, e.g. 29.37863
d(F)(1) # Density of this distribution is 0.1591549 for x=1 .
p(F)(1) # Probability that x<1 is 0.5.
q(F)(.1) # Probability that x<0.02508563 is 0.1.
df1(F) # df1 of this distribution is 1.
df1(F)=2 # df1 of this distribution is now 2.
}
\keyword{}

\eof
\name{Gamma-class}
\docType{class}
\alias{Gamma-class}
\alias{Gamma}
\alias{initialize,Gamma-method}

\title{Class "Gamma"}
\description{   The Gamma distribution with parameters \code{shape} \eqn{=\alpha}{= a},
  by default \code{= 1}, and \code{scale} \eqn{=\sigma}{= s}, by default \code{= 1}, has 
  density
  \deqn{
    d(x)= \frac{1}{{\sigma}^{\alpha}\Gamma(\alpha)} {x}^{\alpha-1} e^{-x/\sigma}%
  }{d(x)= 1/(s^a Gamma(a)) x^(a-1) e^-(x/s)}
  for \eqn{x > 0}, \eqn{\alpha > 0}{a > 0} and \eqn{\sigma > 0}{s > 0}.
  The mean and variance are
  \eqn{E(X) = \alpha\sigma}{E(X) = a*s} and
  \eqn{Var(X) = \alpha\sigma^2}{Var(X) = a*s^2}. C.f. \code{\link{rgamma}} 
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Gamma(scale, shape)}.
This object is a gamma distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"GammaParameter"}: the parameter of this distribution (scale and shape),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function rgamma)}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function dgamma)}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function pgamma)}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function qgamma)}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Gamma")}: initialize method }
    \item{scale}{\code{signature(object = "Gamma")}: returns the slot \code{scale} of the parameter of the distribution }
    \item{scale<-}{\code{signature(object = "Gamma")}: modifies the slot \code{scale} of the parameter of the distribution }
    \item{shape}{\code{signature(object = "Gamma")}: returns the slot \code{shape} of the parameter of the distribution }
    \item{shape<-}{\code{signature(object = "Gamma")}: modifies the slot \code{shape} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{GammaParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rgamma}}





}
\examples{
G=Gamma(scale=1,shape=1) # G is a gamma distribution with scale=1 and shape=1.
r(G)(1) # one random number generated from this distribution, e.g. 0.1304441
d(G)(1) # Density of this distribution is 0.3678794 for x=1.
p(G)(1) # Probability that x<1 is 0.6321206.
q(G)(.1) # Probability that x<0.1053605 is 0.1.
scale(G) # scale of this distribution is 1.
scale(G)=2 # scale of this distribution is now 2.
}
\keyword{}

\eof
\name{GammaParameter-class}
\docType{class}
\alias{GammaParameter-class}
\alias{initialize,GammaParameter-method}

\title{Class "GammaParameter"}
\description{ The parameter of a gamma distribution, used by \code{Gamma}-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("GammaParameter", shape, scale)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class \code{Gamma}
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{shape}:}{Object of class \code{"numeric"}: the shape of a Gamma distribution }
    \item{\code{scale}:}{Object of class \code{"numeric"}: the scale of a Gamma distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "GammaParameter")}: initialize method }
    \item{scale}{\code{signature(object = "GammaParameter")}: returns the slot \code{scale} of a parameter of a Gamma distribution }
    \item{scale<-}{\code{signature(object = "GammaParameter")}: modifies the slot \code{scale} of a parameter of a Gamma
    distribution }
    \item{shape}{\code{signature(object = "GammaParameter")}: returns the slot \code{shape} of a parameter of a Gamma distribution }
    \item{shape<-}{\code{signature(object = "GammaParameter")}: modifies the slot \code{shape} of a parameter of a Gamma
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Gamma-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("GammaParameter",scale=1,shape=1)
shape(W) # shape of this distribution is 1.
shape(W)=2 # shape of this distribution is now 2.
}
\keyword{}

\eof
\name{Geom-class}
\docType{class}
\alias{Geom-class}
\alias{Geom}
\alias{initialize,Geom-method}

\title{Class "Geom" }
\description{
  The geometric distribution with \code{prob} \eqn{= p} has density
  \deqn{p(x) = p {(1-p)}^{x}}{p(x) = p (1-p)^x}
  for \eqn{x = 0, 1, 2, \ldots}{x = 0, 1, 2, ...}
  
  C.f. \code{\link{rgeom}}
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{Geom(prob)}.
  This object is a geometric distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}:
      The space of the image of this distribution has got dimension 1
      and the name "Natural Space".}
    \item{\code{param}:}{Object of class \code{"GeomParameter"}:
      the parameter of this distribution (prob), declared at its
      instantiation}
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers (calls function rgeom)}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function (calls function dgeom)}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative function (calls function pgeom)}
    \item{\code{q}:}{Object of class \code{"function"}:
      inverse of the cumulative function (calls function qgeom).
      The quantile is defined as the smallest value \eqn{x} such that
      \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.}      
    \item{\code{support}:}{Object of class \code{"numeric"}:
      a (sorted) vector containing the support of the discrete density
      function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Geom")}: initialize method}
    \item{prob}{\code{signature(object = "Geom")}:
      returns the slot prob of the parameter of the distribution}
    \item{prob<-}{\code{signature(object = "Geom")}:
      modifies the slot prob of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\note{ Working with a computer, we use a finite interval as support
  which carries at least mass (1-TruncQuantile).}
\seealso{
\code{\link{GeomParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
\code{\link{rgeom}}
}
\examples{
G <- Geom(prob = 0.5) # G is a geometric distribution with prob = 0.5.
r(G)(1) # one random number generated from this distribution, e.g. 0
d(G)(1) # Density of this distribution is 0.25 for x = 1.
p(G)(1) # Probability that x<1 is 0.75.
q(G)(.1) # x = 0 is the smallest value x such that p(G)(x) >= 0.1.
prob(G) # prob of this distribution is 0.5.
prob(G) <- 0.6 # prob of this distribution is now 0.6.
}
\keyword{}

\eof
\name{GeomParameter-class}
\docType{class}
\alias{GeomParameter-class}
\alias{initialize,GeomParameter-method}

\title{Class "GeomParameter"}
\description{ The parameter of a geometric distribution, used by Geom-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("GeomParameter", prob)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Geom
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{prob}:}{Object of class \code{"numeric"}: the probability of a geometric distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "GeomParameter")}: initialize method }
    \item{prob}{\code{signature(object = "GeomParameter")}: returns the slot \code{prob} of the parameter of the
    distribution }
    \item{prob<-}{\code{signature(object = "GeomParameter")}: modifies the slot \code{prob} of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Geom-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("GeomParameter",prob=0.5)
prob(W) # prob of this distribution is 0.5.
prob(W)=0.4 # prob of this distribution is now 0.4.
}
\keyword{}

\eof
\name{Hyper-class}
\docType{class}
\alias{Hyper-class}
\alias{Hyper}
\alias{initialize,Hyper-method}

\title{Class "Hyper" }
\description{  The hypergeometric distribution is used for sampling \emph{without}
  replacement.  The density of this distribution with parameters
  \code{m}, \code{n} and \code{k} (named \eqn{Np}, \eqn{N-Np}, and
  \eqn{n}, respectively in the reference below) is given by
  \deqn{
    p(x) = \left. {m \choose x}{n \choose k-x} \right/ {m+n \choose k}%
  }{p(x) =      choose(m, x) choose(n, k-x) / choose(m+n, k)}
  for \eqn{x = 0, \ldots, k}{x = 0, ..., k}.
  C.f. \code{\link{rhyper}} 
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Hyper(m, n, k)}.
This object is a hypergeometric distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}: The space of the image of this
     distribution has got dimension 1 and the name "Natural Space". }
    \item{\code{param}:}{Object of class \code{"HyperParameter"}: the parameter of this distribution (\code{m}, \code{n}, \code{k}),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rhyper}) }
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dhyper}) }
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{phyper}) }
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qhyper}).
    The \eqn{\alpha}{alpha}-quantile is defined as the smallest value \eqn{x} such that 
     \eqn{p(x) \ge \alpha]}{p(x) >= alpha}, where \eqn{p} is the cumulative function. }
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted) vector containing the support of the discrete
    density function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Hyper")}: initialize method }
    \item{m}{\code{signature(object = "Hyper")}: returns the slot \code{m} of the parameter of the distribution }
    \item{m<-}{\code{signature(object = "Hyper")}: modifies the slot \code{m} of the parameter of the distribution }
    \item{n}{\code{signature(object = "Hyper")}: returns the slot \code{n} of the parameter of the distribution }
    \item{n<-}{\code{signature(object = "Hyper")}: modifies the slot \code{n} of the parameter of the distribution }
    \item{k}{\code{signature(object = "Hyper")}: returns the slot \code{k} of the parameter of the distribution }
    \item{k<-}{\code{signature(object = "Hyper")}: modifies the slot \code{k} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{HyperParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
\code{\link{rhyper}}
}
\examples{
H=Hyper(m=3,n=3,k=3) # H is a hypergeometric distribution with m=3,n=3,k=3.
r(H)(1) # one random number generated from this distribution, e.g. 2
d(H)(1) # Density of this distribution is  0.45 for x=1.
p(H)(1) # Probability that x<1 is 0.5.
q(H)(.1) # x=1 is the smallest value x such that p(H)(x)>=0.1.
m(H) # m of this distribution is 3.
m(H)=2 # m of this distribution is now 2.
}
\keyword{}

\eof
\name{HyperParameter-class}
\docType{class}
\alias{HyperParameter-class}
\alias{initialize,HyperParameter-method}

\title{Class "HyperParameter"}
\description{ The parameter of a hypergeometric distribution, used by \code{Hyper}-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("HyperParameter", k, m, n)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class \code{Hyper}
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{k}:}{Object of class \code{"numeric"}: k of a hypergeometric distribution }
    \item{\code{m}:}{Object of class \code{"numeric"}: m of a hypergeometric distribution }
    \item{\code{n}:}{Object of class \code{"numeric"}: n of a hypergeometric distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "HyperParameter")}: initialize method }
    \item{k}{\code{signature(object = "HyperParameter")}: returns the slot \code{k} of the parameter of the distribution }
    \item{k<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{k} of the parameter of the distribution }
    \item{m}{\code{signature(object = "HyperParameter")}: returns the slot \code{m} of the parameter of the distribution }
    \item{m<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{m} of the parameter of the distribution }
    \item{n}{\code{signature(object = "HyperParameter")}: returns the slot \code{n} of the parameter of the distribution }
    \item{n<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{n} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Hyper-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("HyperParameter",k=3, m=3, n=3)
m(W) # m of this distribution is 3.
m(W)=2 # m of this distribution is now 2.
}
\keyword{}

\eof
\name{Lnorm-class}
\docType{class}
\alias{Lnorm-class}
\alias{Lnorm}
\alias{initialize,Lnorm-method}

\title{Class "Lnorm"}
\description{ 
  The log normal distribution has density
  \deqn{
    d(x) = \frac{1}{\sqrt{2\pi}\sigma x} e^{-(\log(x) - \mu)^2/2 \sigma^2}%
  }{d(x) = 1/(sqrt(2 pi) sigma x) e^-((log x - mu)^2 / (2 sigma^2))}
  where \eqn{\mu}, by default \eqn{=0}, and \eqn{\sigma}, by default \eqn{=1}, are the mean and standard
  deviation of the logarithm.
C.f. \code{\link{rlnorm}} }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Lnorm(meanlog, sdlog)}.
This object is a log normal distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"LnormParameter"}: the parameter of this distribution (meanlog and sdlog),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rlnorm})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dlnorm})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{plnorm})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qlnorm})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Lnorm")}: initialize method }
    \item{meanlog}{\code{signature(object = "Lnorm")}: returns the slot \code{meanlog} of the parameter of the distribution }
    \item{meanlog<-}{\code{signature(object = "Lnorm")}: modifies the slot \code{meanlog} of the parameter of the distribution }
    \item{sdlog}{\code{signature(object = "Lnorm")}: returns the slot \code{sdlog} of the parameter of the distribution }
    \item{sdlog<-}{\code{signature(object = "Lnorm")}: modifies the slot \code{sdlog} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{  The mean is \eqn{E(X) = exp(\mu + 1/2 \sigma^2)}, and the variance
  \eqn{Var(X) = exp(2\mu + \sigma^2)(exp(\sigma^2) - 1)}{%
    Var(X) = exp(2*mu + sigma^2)*(exp(sigma^2) - 1)} and
  hence the coefficient of variation is
  \eqn{\sqrt{exp(\sigma^2) - 1}}{sqrt(exp(sigma^2) - 1)} which is
    approximately \eqn{\sigma} when that is small (e.g., \eqn{\sigma < 1/2}).
%% Mode = exp(max(0, mu - sigma^2)); Median = exp(mu)
}

\seealso{
\code{\link{LnormParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rlnorm}}





}
\examples{
L=Lnorm(meanlog=1,sdlog=1) # L is a lnorm distribution with mean=1 and sd=1.
r(L)(1) # one random number generated from this distribution, e.g. 3.608011
d(L)(1) # Density of this distribution is 0.2419707 for x=1.
p(L)(1) # Probability that x<1 is 0.1586553.
q(L)(.1) # Probability that x<0.754612 is 0.1.
meanlog(L) # meanlog of this distribution is 1.
meanlog(L)=2 # meanlog of this distribution is now 2.
}
\keyword{}

\eof
\name{LnormParameter-class}
\docType{class}
\alias{LnormParameter-class}
\alias{initialize,LnormParameter-method}

\title{Class "LnormParameter"}
\description{ The parameter of a log normal distribution, used by Lnorm-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LnormParameter", meanlog, sdlog)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Lnorm
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{meanlog}:}{Object of class \code{"numeric"}: the mean of a log normal distribution }
    \item{\code{sdlog}:}{Object of class \code{"numeric"}: the sd of a log normal distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "LnormParameter")}: initialize method }
    \item{sdlog}{\code{signature(object = "LnormParameter")}: returns the slot sdlog of the parameter of the distribution }
    \item{sdlog<-}{\code{signature(object = "LnormParameter")}: modifies the slot sdlog of the parameter of the
    distribution }
    \item{meanlog}{\code{signature(object = "LnormParameter")}: returns the slot meanlog of the parameter of the
    distribution}
    \item{meanlog<-}{\code{signature(object = "LnormParameter")}: modifies the slot meanlog of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{Lnorm-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("LnormParameter",sdlog=1,meanlog=0)
meanlog(W) # meanlog of this distribution is 0.
meanlog(W)=2 # meanlog of this distribution is now 2.
}
\keyword{}

\eof
\name{Logis-class}
\docType{class}
\alias{Logis-class}
\alias{Logis}
\alias{initialize,Logis-method}

\title{Class "Logis"}
\description{ The Logistic distribution with \code{location} \eqn{= \mu}{= m}, 
  by default \code{= 0}, and \code{scale} \eqn{= \sigma}{= s}, by default \code{= 1}, 
  has distribution function
  \deqn{
    p(x) = \frac{1}{1 + e^{-(x-\mu)/\sigma}}%
  }{p(x) = 1 / (1 + exp(-(x-m)/s))}  and density
  \deqn{
    d(x)= \frac{1}{\sigma}\frac{e^{(x-\mu)/\sigma}}{(1 + e^{(x-\mu)/\sigma})^2}%
  }{d(x) = 1/s exp((x-m)/s) (1 + exp((x-m)/s))^-2.}

  It is a long-tailed distribution with mean \eqn{\mu}{m} and variance
  \eqn{\pi^2/3 \sigma^2}{pi^2 /3 s^2}. C.f. \code{\link{rlogis}} 
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Logis(location, scale)}.
This object is a logistic distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"LogisParameter"}: the parameter of this distribution (location and scale),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function rlogis)}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function dlogis)}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function plogis)}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function qlogis)}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Logis")}: initialize method }
    \item{location}{\code{signature(object = "Logis")}: returns the slot \code{location} of the parameter of the distribution }
    \item{location<-}{\code{signature(object = "Logis")}: modifies the slot \code{location} of the parameter of the distribution }
    \item{scale}{\code{signature(object = "Logis")}: returns the slot \code{scale} of the parameter of the distribution }
    \item{scale<-}{\code{signature(object = "Logis")}: modifies the slot \code{scale} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{LogisParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rlogis}}





}
\examples{
L <- Logis(location = 1,scale = 1)
# L is a logistic distribution with  location = 1 and scale = 1.
r(L)(1) # one random number generated from this distribution, e.g. 5.87557
d(L)(1) # Density of this distribution is 0.25 for x = 1.
p(L)(1) # Probability that x < 1 is 0.5.
q(L)(.1) # Probability that x < -1.197225 is 0.1.
location(L) # location of this distribution is 1.
location(L) <- 2 # location of this distribution is now 2.
}
\keyword{}

\eof
\name{LogisParameter-class}
\docType{class}
\alias{LogisParameter-class}
\alias{initialize,LogisParameter-method}

\title{Class "LogisParameter"}
\description{ The parameter of a logistic distribution, used by \code{Logis}-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LogisParameter", scale, location)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class 
\code{Logis} is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{scale}:}{Object of class \code{"numeric"}: the scale of a logistic distribution }
    \item{\code{location}:}{Object of class \code{"numeric"}: the location of a logistic distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "LogisParameter")}: initialize method }
    \item{location}{\code{signature(object = "LogisParameter")}: returns the slot \code{location} of the parameter of the
    distribution }
    \item{location<-}{\code{signature(object = "LogisParameter")}: modifies the slot \code{location} of the parameter of the
    distribution }
    \item{scale}{\code{signature(object = "LogisParameter")}: returns the slot \code{scale} of the parameter of the distribution }
    \item{scale<-}{\code{signature(object = "LogisParameter")}: modifies the slot \code{scale} of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Logis-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("LogisParameter",location=0,scale=1)
scale(W) # scale of this distribution is 1.
scale(W)=2 # scale of this distribution is now 2.
}
\keyword{}

\eof
\name{Math-methods}
\docType{methods}
\alias{Math-methods}
\alias{Math,AbscontDistribution-method}
\alias{Math,DiscreteDistribution-method}
\title{ Methods for Function Math in Package `distr' }
\description{Math-methods}

\section{Methods}{\describe{
    \item{Math}{\code{signature(x = "AbscontDistribution")}: application of a
      mathematical function, e.g. sin or exp (does not work with log!), to this
      absolutely continouos distribution}
    \item{Math}{\code{signature(x = "AbscontDistribution")}: application of a
      mathematical function, e.g. sin or exp (does not work with log!), to this
      discrete distribution}
}}
\keyword{}

\eof
\name{Max-methods}
\docType{methods}
\alias{Max-methods}
\alias{Max<--methods}
\alias{Max}
\alias{Max<-}
\alias{Max,UnifParameter-method}
\alias{Max,Unif-method}
\alias{Max<-,UnifParameter-method}
\alias{Max<-,Unif-method}
\title{ Methods for Function Max in Package `distr' }
\description{Max-methods}

\section{Methods}{\describe{

\item{Max}{\code{signature(object = "UnifParameter")}: returns the slot \code{Max} of the parameter of the distribution }
\item{Max<-}{\code{signature(object = "UnifParameter")}: modifies the slot \code{Max} of the parameter of the distribution }

\item{Max}{\code{signature(object = "Unif")}: returns the slot \code{Max} of the parameter of the distribution }
\item{Max<-}{\code{signature(object = "Unif")}: modifies the slot \code{Max} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{Min-methods}
\docType{methods}
\alias{Min-methods}
\alias{Min<--methods}
\alias{Min}
\alias{Min<-}
\alias{Min,UnifParameter-method}
\alias{Min,Unif-method}
\alias{Min<-,UnifParameter-method}
\alias{Min<-,Unif-method}
\title{ Methods for Function Min in Package `distr' }
\description{Min-methods}

\section{Methods}{\describe{

\item{Min}{\code{signature(object = "UnifParameter")}: returns the slot \code{Min} of the parameter of the distribution }
\item{Min<-}{\code{signature(object = "UnifParameter")}: modifies the slot \code{Min} of the parameter of the distribution }

\item{Min}{\code{signature(object = "Unif")}: returns the slot \code{Min} of the parameter of the distribution }
\item{Min<-}{\code{signature(object = "Unif")}: modifies the slot \code{Min} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{Naturals-class}
\docType{class}
\alias{Naturals-class}
\alias{initialize,Naturals-method}

\title{Class "Naturals" }
\description{ The distribution-classes contain a slot where the sample space is stored. Typically, discrete random
variables take naturals as values. }
\section{Objects from the Class}{
Objects could theoretically be created by calls of the form \code{new("Naturals", dimension, name)}.
Usually an object of this class is not needed on its own. It is generated automatically when a univariate discrete
distribution is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{dimension}:}{Object of class \code{"character"}: the dimension of the space, by default = 1 }
    \item{\code{name}:}{Object of class \code{"character"}: the name of the space, by default = "Natural Space"}
  }
}
\section{Extends}{
Class \code{"Reals"}, directly.\cr
Class \code{"EuclideanSpace"}, by class \code{"Reals"}.\cr
Class \code{"rSpace"}, by class \code{"Reals"}.
}

\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Naturals")}: initialize method }
    \item{liesIn}{\code{signature(object = "Naturals", x = "numeric")}: Does a particular vector only contain naturals? }
}
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{Reals-class}}
\code{\link{DiscreteDistribution-class}}
}

\examples{
N=new("Naturals")
liesIn(N,1) # TRUE
liesIn(N,c(0,1)) # FALSE
liesIn(N,0.1) # FALSE
}


\keyword{}

\eof
\name{Nbinom-class}
\docType{class}
\alias{Nbinom-class}
\alias{Nbinom}
\alias{initialize,Nbinom-method}

\title{Class "Nbinom" }
\description{
  The negative binomial distribution with \code{size} \eqn{= n}, by default \eqn{=1}, and
  \code{prob} \eqn{= p}, by default \eqn{=0.5}, has density
  \deqn{
    d(x) = \frac{\Gamma(x+n)}{\Gamma(n) x!} p^n (1-p)^x}{%
    d(x) = Gamma(x+n)/(Gamma(n) x!) p^n (1-p)^x}
  for \eqn{x = 0, 1, 2, \ldots}

  This represents the number of failures
  which occur in a sequence of Bernoulli trials before a target number
  of successes is reached.
  C.f. \code{\link{rnbinom}} 
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Nbinom(prob, size)}.
This object is a negative binomial distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}: The space of the image of this
     distribution has got dimension 1 and the name "Natural Space". }
    \item{\code{param}:}{Object of class \code{"NbinomParameter"}: the parameter of this distribution (prob, size),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rnbinom}) }
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dnbinom}) }
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pnbinom}) }
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qnbinom}).
  The quantile is defined as the smallest value \eqn{x} such that
  \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.}
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted) vector containing the support of the discrete
    density function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Nbinom")}: initialize method }
    \item{prob}{\code{signature(object = "Nbinom")}: returns the slot \code{prob} of the parameter of the distribution }
    \item{prob<-}{\code{signature(object = "Nbinom")}: modifies the slot \code{prob} of the parameter of the distribution }
    \item{size}{\code{signature(object = "Nbinom")}: returns the slot \code{size} of the parameter of the distribution }
    \item{size<-}{\code{signature(object = "Nbinom")}: modifies the slot \code{size} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\note{ Working with a computer, we use a finite interval as support which carries at least mass \eqn{1-TruncQuantile}. }

\seealso{
\code{\link{NbinomParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
\code{\link{rnbinom}}
}
\examples{
N=Nbinom(prob=0.5,size=1) # N is a binomial distribution with prob=0.5 and size=1.
r(N)(1) # one random number generated from this distribution, e.g. 3
d(N)(1) # Density of this distribution is  0.25 for x=1.
p(N)(0.4) # Probability that x<0.4 is 0.5.
q(N)(.1) # x=0 is the smallest value x such that p(B)(x)>=0.1.
size(N) # size of this distribution is 1.
size(N)=2 # size of this distribution is now 2.
}
\keyword{}

\eof
\name{NbinomParameter-class}
\docType{class}
\alias{NbinomParameter-class}
\alias{initialize,NbinomParameter-method}

\title{Class "NbinomParameter"}
\description{ The parameter of a negative binomial distribution, used by Nbinom-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("NbinomParameter", prob, size)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class Nbinom
is prepared. 
}
\section{Slots}{
  \describe{
    \item{\code{prob}:}{Object of class \code{"numeric"}: the probability of a negative binomial distribution }
    \item{\code{size}:}{Object of class \code{"numeric"}: the size of a negative binomial distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "NbinomParameter")}: initialize method }
    \item{prob}{\code{signature(object = "NbinomParameter")}: returns the slot \code{prob} of the parameter of the
    distribution }
    \item{prob<-}{\code{signature(object = "NbinomParameter")}: modifies the slot \code{prob} of the parameter of the
    distribution }
    \item{size}{\code{signature(object = "NbinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
    \item{size<-}{\code{signature(object = "NbinomParameter")}: modifies the slot \code{size} of the parameter of the
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Nbinom-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("NbinomParameter",prob=0.5,size=1)
size(W) # size of this distribution is 1.
size(W)=2 # size of this distribution is now 2.
}
\keyword{}

\eof
\name{Norm-class}
\docType{class}
\alias{Norm-class}
\alias{Norm}
\alias{initialize,Norm-method}

\title{Class "Norm"}
\description{  The normal distribution has density
  \deqn{
    f(x) =
    \frac{1}{\sqrt{2\pi}\sigma} e^{-(x-\mu)^2/2\sigma^2}}{
    f(x) = 1/(sqrt(2 pi) sigma) e^-((x - mu)^2/(2 sigma^2))
  }
  where \eqn{\mu}{mu} is the mean of the distribution and
  \eqn{\sigma}{sigma} the standard deviation.
 C.f. \code{\link{rnorm}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Norm(mean, sd)}.
This object is a normal distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The domain of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"UniNormParameter"}: the parameter of this distribution (mean and sd),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rnorm})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dnorm})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pnorm})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qnorm})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{*}{\code{signature(e1 = "numeric", e2 = "Norm")}: multiplication of this normal distribution by an object of
    class `numeric'}
    \item{+}{\code{signature(e1 = "numeric", e2 = "Norm")}: addition of this normal distribution to an object of class
    `numeric'}
    \item{-}{\code{signature(e1 = "numeric", e2 = "Norm")}: subtraction of this normal distribution from an object of
    class `numeric'}
    \item{*}{\code{signature(e1 = "Norm", e2 = "numeric")}: multiplication of this normal distribution by an object of
    class `numeric'}
    \item{+}{\code{signature(e1 = "Norm", e2 = "numeric")}: addition of this normal distribution to an object of class
    `numeric'}
    \item{-}{\code{signature(e1 = "Norm", e2 = "numeric")}: subtraction of an object of class `numeric' from this normal
    distribution }
    \item{/}{\code{signature(e1 = "Norm", e2 = "numeric")}: division of this normal distribution by an object of class
    `numeric'}
    \item{-}{\code{signature(e1 = "Norm", e2 = "Norm")}}
    \item{+}{\code{signature(e1 = "Norm", e2 = "Norm")}: 
    For the normal distribution the exact convolution formulas are implemented thereby improving the general numerical
    approximation.}
    \item{initialize}{\code{signature(.Object = "Norm")}: initialize method }
    \item{mean}{\code{signature(object = "Norm")}: returns the slot \code{mean} of the parameter of the distribution }
    \item{mean<-}{\code{signature(object = "Norm")}: modifies the slot \code{mean} of the parameter of the distribution }
    \item{sd}{\code{signature(object = "Norm")}: returns the slot \code{sd} of the parameter of the distribution  }
    \item{sd<-}{\code{signature(object = "Norm")}: modifies the slot \code{sd} of the parameter of the distribution }
  }

}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{UniNormParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rnorm}}

}
\examples{
N=Norm(mean=1,sd=1) # N is a normal distribution with mean=1 and sd=1.
r(N)(1) # one random number generated from this distribution, e.g. 2.257783
d(N)(1) # Density of this distribution is  0.3989423 for x=1.
p(N)(1) # Probability that x<1 is 0.5.
q(N)(.1) # Probability that x<-0.2815516 is 0.1.
mean(N) # mean of this distribution is 1.
sd(N)=2 # sd of this distribution is now 2.
M=Norm() # M is a normal distribution with mean=0 and sd=1.
O=M+N # O is a normal distribution with mean=1 (=1+0) and sd=sqrt(5) (=sqrt(2^2+1^2)).
}
\keyword{}

\eof
\name{NormParameter-class}
\docType{class}
\alias{NormParameter-class}
\alias{initialize,NormParameter-method}
\title{Class "NormParameter"}
\description{ The parameter of a normal distribution, used by Norm-class}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("NormParameter", sd, mean)}.
  Usually an object of this class is not needed on its own. It is the
  mother-class of the class UniNormParameter, which is generated
  automatically when such a distribution is instantiated.  
}
\section{Slots}{
  \describe{
    \item{\code{sd}:}{Object of class \code{"numeric"}: the sd of a normal distribution }
    \item{\code{mean}:}{Object of class \code{"numeric"}: the mean of a normal distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "NormParameter")}:
      initialize method}
    \item{mean}{\code{signature(object = "NormParameter")}:
      returns the slot mean of the parameter of the distribution} 
    \item{mean<-}{\code{signature(object = "NormParameter")}:
      modifies the slot mean of the parameter of the distribution} 
    \item{sd}{\code{signature(object = "NormParameter")}:
      returns the slot sd of the parameter of the distribution}
    \item{sd<-}{\code{signature(object = "NormParameter")}:
      modifies the slot sd of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Norm-class}}
\code{\link{Parameter-class}}
}
\examples{
W <- new("NormParameter", mean = 0, sd = 1)
sd(W) # sd of this distribution is 1.
sd(W) <- 2 # sd of this distribution is now 2.
}
\keyword{}

\eof
\name{OptionalParameter-class}
\docType{class}
\alias{OptionalParameter-class}

\title{Class "OptionalParameter" }
\description{ auxiliary class; may contain either a Parameter or NULL, cf. J. Chambers, "green book".}
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
No methods defined with class "OptionalParameter" in the signature.
}
\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\code{\link{Parameter-class}}
\keyword{}

\eof
\name{Parameter-class}
\docType{class}
\alias{Parameter-class}
\title{Class "Parameter"}
\description{
  Parameter is the mother-class of all Parameter classes.
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("Parameter")}.
}
\section{Slots}{
  \describe{
    \item{\code{name}:}{Object of class \code{"character"}:
      a name / comment for the parameters}
  }
}
\section{Methods}{
  \describe{
    \item{name}{\code{signature(object = "Parameter")}:
      returns the name of the parameter}
    \item{name<-}{\code{signature(object = "Parameter")}:
      modifies the name of the parameter}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Distribution-class}}
}
\keyword{}

\eof
\name{Pois-class}
\docType{class}
\alias{Pois-class}
\alias{Pois}
\alias{initialize,Pois-method}
\title{Class "Pois" }
\description{
  The Poisson distribution has density
%-- please leave the linebreaking for the next two ! --
  \deqn{p(x) = \frac{\lambda^x e^{-\lambda}}{x!}}{%
        p(x) = lambda^x exp(-lambda)/x!}
  for \eqn{x = 0, 1, 2, \ldots}.  The mean and variance are
  \eqn{E(X) = Var(X) = \lambda}.

  C.f. \code{\link{rpois}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Pois(lambda)}.
This object is a Poisson distribution. 
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Naturals"}:
      The space of the image of this distribution has got dimension 1
      and the name "Natural Space".}
    \item{\code{param}:}{Object of class \code{"PoisParameter"}:
      the parameter of this distribution (lambda), declared at its
      instantiation}
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers (calls function rpois)}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function (calls function dpois)}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative function (calls function ppois)}
    \item{\code{q}:}{Object of class \code{"function"}:
      inverse of the cumulative function (calls function qpois).
      The quantile is defined as the smallest value \eqn{x} such that
      \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.}
    \item{\code{support}:}{Object of class \code{"numeric"}: a (sorted)
      vector containing the support of the discrete density function}
  }
}
\section{Extends}{
Class \code{"DiscreteDistribution"}, directly.
Class \code{"UnivariateDistribution"}, by class \code{"DiscreteDistribution"}.
Class \code{"Distribution"}, by class \code{"DiscreteDistribution"}.
}
\section{Methods}{
  \describe{
    \item{+}{\code{signature(e1 = "Pois", e2 = "Pois")}:
      For the Poisson distribution the exact convolution formula is
      implemented thereby improving the general numerical approximation.}
    \item{initialize}{\code{signature(.Object = "Pois")}:
      initialize method}
    \item{lambda}{\code{signature(object = "Pois")}:
      returns the slot lambda of the parameter of the distribution}
    \item{lambda<-}{\code{signature(object = "Pois")}:
      modifies the slot lambda of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\note{
  Working with a computer, we use a finite interval as support which
  carries at least mass (1-TruncQuantile).
} 
\seealso{
\code{\link{PoisParameter-class}}
\code{\link{DiscreteDistribution-class}}
\code{\link{Naturals-class}}
\code{\link{rpois}}
}
\examples{
P <- Pois(lambda = 1) # P is a Poisson distribution with lambda = 1.
r(P)(1) # one random number generated from this distribution, e.g. 1
d(P)(1) # Density of this distribution is 0.3678794 for x = 1.
p(P)(0.4) # Probability that x < 0.4 is 0.3678794.
q(P)(.1) # x = 0 is the smallest value x such that p(B)(x) >= 0.1.
lambda(P) # lambda of this distribution is 1.
lambda(P) <- 2 # lambda of this distribution is now 2.
R <- Pois(lambda = 3) # R is a Poisson distribution with lambda = 2.
S <- P + R # R is a Poisson distribution with lambda = 5(=2+3).
}
\keyword{}

\eof
\name{PoisParameter-class}
\docType{class}
\alias{PoisParameter-class}
\alias{initialize,PoisParameter-method}
\title{Class "PoisParameter"}
\description{ The parameter of a Poisson distribution, used by Pois-class}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("PoisParameter", lambda)}.
  Usually an object of this class is not needed on its own, it is
  generated automatically when an object of the class Pois is prepared. 
}
\section{Slots}{
  \describe{
    \item{\code{lambda}:}{Object of class \code{"numeric"}:
      the lambda of a Poisson distribution}
    \item{\code{name}:}{Object of class \code{"character"}:
      a name / comment for the parameters}
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "PoisParameter")}:
      initialize method }
    \item{lambda}{\code{signature(object = "PoisParameter")}:
      returns the slot lambda of the parameter of the distribution}
    \item{lambda<-}{\code{signature(object = "PoisParameter")}:
      modifies the slot lambda of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Pois-class}}
\code{\link{Parameter-class}}
}
\examples{
W <- new("PoisParameter",lambda = 1)
lambda(W) # lambda of this distribution is 1.
lambda(W) <- 2 # lambda of this distribution is now 2.
}
\keyword{}

\eof
\name{Reals-class}
\docType{class}
\alias{Reals-class}
\alias{initialize,Reals-method}

\title{Class "Reals" }
\description{ Particular case of a one-dimensional Euclidean Space }
\section{Objects from the Class}{
Objects could theoretically be created by calls of the form \code{new("Reals", dimension, name)}.
Usually an object of this class is not needed on its own. It is generated automatically when a univariate absolutly
continuous distribution is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{dimension}:}{Object of class \code{"character"}: the dimension of the space, by default = 1 }
    \item{\code{name}:}{Object of class \code{"character"}: the name of the space, by default = "Real Space"}
  }
}
\section{Extends}{
Class \code{"EuclideanSpace"}, directly.\cr
Class \code{"rSpace"}, by class \code{"EuclideanSpace"}.
}

\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Reals")}: initialize method }
}
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{EuclideanSpace-class}}
\code{\link{Naturals-class}}
\code{\link{AbscontDistribution-class}}
}

\examples{
R=new("Reals")
liesIn(R,c(0,0)) # FALSE
}


\keyword{}

\eof
\name{RtoDPQ}
\alias{RtoDPQ}
\title{RtoDPQ}
\description{
function to do get empirical density, cumulative distribution and quantile function from random numbers}
\usage{
RtoDPQ(r, e = RtoDPQ.e, n = DefaultNrGridPoints)
}
\arguments{
  \item{r}{ the random number generator }
  \item{e}{ \eqn{10^e} numbers are generated, a higher number leads to a better result. }
  \item{n}{ The number of grid points used to create the approximated functions, a higher number leads to a better result.}
}
\details{
RtoDPQ generates \eqn{10^e} random numbers, by default \deqn{e = RtoDPQ.e}. The density is formed on the basis of \eqn{n}
points using approxfun and density, by default \deqn{n = DefaultNrGridPoints}.
The cumulative distribution function and the quantile function are also created on the basis of \eqn{n} points using 
\code{approxfun} and \code{ecdf}.  Of course, the results are usually not exact as they rely on random numbers.}
\value{ \code{RtoDPQ} returns a list of functions.
  \item{dfun }{ density }
  \item{pfun }{ cumulative distribution function }
  \item{qfun }{ quantile function }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{ Use \code{RtoDPQ} for absolutely continuous and \code{RtoDPQ.d} for discrete distributions. }

\seealso{ 
\code{\link{UnivariateDistribution-class}}}
\code{\link{density}}}
\code{\link{approxfun}}}
\code{\link{ecdf}}}
\examples{
rn2 <- function(n){rnorm(n)^2}
x <- RtoDPQ(r = rn2, e = 4, n = 512)
# returns density, cumulative distribution and quantile function of
# squared standard normal distribution
x$dfun(4)
RtoDPQ(r = rn2, e = 5, n = 1024) # for a better result

rp2 <- function(n){rpois(n, lambda = 1)^2}
x <- RtoDPQ.d(r = rp2, e = 5)
# returns density, cumulative distribution and quantile function of
# squared Poisson distribution with parameter lambda=1
}
\keyword{}

\eof
\name{RtoDPQ.d}
\alias{RtoDPQ.d}
\title{RtoDPQ.d}
\description{
function to do get empirical density, cumulative distribution and quantile function from random numbers}
\usage{
RtoDPQ.d(r, e = RtoDPQ.e)
}
\arguments{
  \item{r}{ the random number generator }
  \item{e}{ \eqn{10^e} numbers are generated, a higher number leads to a better result. }
}
\details{
  \code{RtoDPQ.d} generates \eqn{10^e} random numbers, by default \eqn{e =}
  \code{RtoDPQ.e} which are used to produce a density, cdf and
  quantile function.
  Of course, the results are usually not exact as they rely on random numbers.}
\value{ RtoDPQ returns a list of functions.
  \item{dfun }{ density }
  \item{pfun }{ cumulative distribution function }
  \item{qfun }{ quantile function }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\note{
  Use RtoDPQ for absolutely continuous and RtoDPQ.d for discrete
  distributions.
}
\seealso{ 
\code{\link{UnivariateDistribution-class}}}
\code{\link{density}}}
\code{\link{approxfun}}}
\code{\link{ecdf}}}
\examples{
rn2 <- function(n){rnorm(n)^2}
x <- RtoDPQ(r = rn2, e = 4, n = 512)
# returns density, cumulative distribution and quantile function of
# squared standard  normal distribution

x$dfun(4)
RtoDPQ(r = rn2, e = 5, n = 1024) # for a better result

rp2 <- function(n){rpois(n, lambda = 1)^2}
x <- RtoDPQ.d(r = rp2, e = 5)
# returns density, cumulative distribution and quantile function of
# squared Poisson distribution with parameter lambda=1
}
\keyword{}

\eof
\name{Simulation-class}
\docType{class}
\alias{Simulation-class}
\alias{Simulation}
\alias{initialize,Simulation-method}

\title{Class "Simulation" }
\description{  In an object of type \code{Simulation} data can be simulated in any distribution and size.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Simulation(filename, runs, samplesize, seed, distribution)}.
A \code{Simulation}-object includes a filename, the number of runs, the size of the sample, the seed and the distribution of the
random numbers. The slot \code{Data} stays empty until the method simulate has been used.}
\section{Slots}{
  \describe{
    \item{\code{seed}:}{Object of class \code{"list"}: the seed the simulation has been generated with }
    \item{\code{distribution}:}{Object of class \code{"UnivariateDistribution"}: the distribution of the random numbers}
    \item{\code{filename}:}{Object of class \code{"character"}: the filename the simulation shall be saved }
    \item{\code{Data}:}{Object of class \code{"vectororNULL"}: the simulated data }
    \item{\code{runs}:}{Object of class \code{"numeric"}: the number of runs of the data }
    \item{\code{samplesize}:}{Object of class \code{"numeric"}: the size of the sample, so the dimension of the data }
  }
}
\section{Extends}{
Class \code{"Dataclass"}, directly.
}
\section{Methods}{
  \describe{
    \item{Data<-}{\code{signature(object = "Contsimulation")}: ERROR: A modification of simulated data is not allowed. }
    \item{distribution}{\code{signature(object = "Simulation")}: returns the distribution }
    \item{distribution<-}{\code{signature(object = "Simulation")}: changes the distribution }
    \item{seed}{\code{signature(object = "Simulation")}: returns the seed }
    \item{seed<-}{\code{signature(object = "Simulation")}: changes the seed }
    \item{runs<-}{\code{signature(object = "Simulation")}: changes the number of runs }
    \item{samplesize<-}{\code{signature(object = "Simulation")}: changes the size of the sample }
    \item{savedata}{\code{signature(object = "Simulation")}: saves the object without the data in the directory of R
    (After loading the data can be reproduced by using simulate.) }
    \item{initialize}{\code{signature(.Object = "Simulation")}: initialize method }
    \item{plot}{\code{signature(x = "Simulation")}: produces a plot of the data matrix }
    \item{print}{\code{signature(x = "Simulation")}: returns filename, seed, number of runs, the size of the sample and the
    distribution }
    \item{simulate}{\code{signature(x = "Simulation")}: generates the random numbers for the simulation }
    \item{summary}{\code{signature(object = "Simulation")}: returns filename, seed, number of runs, the size of the sample
    and a statistical summary for each run }
}}

\note{ Changing distribution, seed, runs or samplesize deletes possibly simulated data, as it would not fit to the new
parameters. }


\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Dataclass-class}}
\code{\link{Contsimulation-class}}
\code{\link{plot-methods}}
\code{\link{print-methods}}
\code{\link{summary-methods}}
\code{\link{simulate-methods}}
}
\examples{
N=Norm() # N is a standard normal distribution.
S=Simulation(filename="xyz",runs=10,samplesize=3,seed=setRNG(),distribution=N)
Data(S) # no data yet
simulate(S)
Data(S) # now there are random numbers
Data(S) # the same data as before because the seed has not changed
seed(S)=setRNG()
simulate(S)
Data(S) # different data
savedata(S) # saves the object in the directory of R...
load("xyz") # loads it again...
Data(S) # ...without the data - use simulate to return it!
}
\keyword{}

\eof
\name{TParameter-class}
\docType{class}
\alias{TParameter-class}
\alias{initialize,TParameter-method}

\title{Class "TParameter"}
\description{ The parameter of a t distribution, used by Td-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("TParameter", df)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class
\code{Td} is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{df}:}{Object of class \code{"numeric"}: the df of a T distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "TParameter")}: initialize method }
    \item{df}{\code{signature(object = "TParameter")}: returns the slot \code{df} of the parameter of the distribution }
    \item{df<-}{\code{signature(object = "TParameter")}: modifies the slot \code{df} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Td-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("TParameter",df=1)
df(W) # df of this distribution is 1.
df(W)=2 # df of this distribution is now 2.
}
\keyword{}

\eof
\name{Td-class}
\docTdype{class}
\alias{Td-class}
\alias{Td}
\alias{initialize,Td-method}

\title{Class "Td"}
\description{  The \eqn{t} distribution with \code{df} \eqn{= \nu}{= n} degrees of
  freedom has density
  \deqn{
    f(x) = \frac{\Gamma ((\nu+1)/2)}{\sqrt{\pi \nu} \Gamma (\nu/2)}
    (1 + x^2/\nu)^{-(\nu+1)/2}%
  }{f(x) = Gamma((n+1)/2) / (sqrt(n pi) Gamma(n/2)) (1 + x^2/n)^-((n+1)/2)}
  for all real \eqn{x}.
  It has mean \eqn{0} (for \eqn{\nu > 1}{n > 1}) and
  variance \eqn{\frac{\nu}{\nu-2}}{n/(n-2)} (for \eqn{\nu > 2}{n > 2}).
 C.f. \code{\link{rt}}   
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Td(df)}.
This object is a \eqn{t} distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The domain of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"TParameter"}: the parameter of this distribution (df),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rt})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dt})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pt})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qt})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Td")}: initialize method }
    \item{df}{\code{signature(object = "Td")}: returns the slot df of the parameter of the distribution }
    \item{df<-}{\code{signature(object = "Td")}: modifies the slot df of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{  The general \emph{non-central} \eqn{t}
  with parameters \eqn{(\nu,\delta)}{(df,Del)} \code{= (df, ncp)}
  is defined as a the distribution of
  \eqn{T_{\nu}(\delta) := \frac{U + \delta}{\chi_{\nu}/\sqrt{\nu}}}{%
      T(df,Del) := (U + Del) / (Chi(df) / sqrt(df)) }
  where \eqn{U} and \eqn{\chi_{\nu}}{Chi(df)}  are independent random
  variables, \eqn{U \sim {\cal N}(0,1)}{U \~ N(0,1)}, and
%%fails  \eqn{{\chi_{\nu}}^2}{(Chi(df))^2}
  \eqn{\chi^2_\nu}{Chi(df)^2}
  is chi-squared, see \code{\link{pchisq}}.

  The most used applications are power calculations for \eqn{t}-tests:\cr
  Let \eqn{T= \frac{\bar{X} - \mu_0}{S/\sqrt{n}}}{T= (mX - m0) / (S/sqrt(n))}
  where
  \eqn{\bar{X}}{mX} is the \code{\link{mean}} and \eqn{S} the sample standard
  deviation (\code{\link{sd}}) of \eqn{X_1,X_2,\dots,X_n} which are i.i.d.
%%fails \eqn{{\cal N}(\mu,\sigma^2)}{N(mu,sigma^2)}
        \eqn{       N(\mu,\sigma^2)}{N(mu,sigma^2)}.
  Then \eqn{T} is distributed as non-centrally \eqn{t} with
  \code{df}\eqn{= n-1}
  degrees of freedom and \bold{n}on-\bold{c}entrality \bold{p}arameter
  \code{ncp}\eqn{= (\mu - \mu_0) \sqrt{n}/\sigma}{= (mu - m0) * sqrt(n)/sigma}.

}
\seealso{
\code{\link{TParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rt}}


}
\examples{
T <- Td(df = 1) # T is a t distribution with df = 1.
r(T)(1) # one random number generated from this distribution, e.g. -0.09697573
d(T)(1) # Density of this distribution is 0.1591549 for x = 1.
p(T)(1) # Probability that x < 1 is 0.75.
q(T)(.1) # Probability that x < -3.077684 is 0.1.
df(T) # df of this distribution is 1.
df(T) <- 2 # df of this distribution is now 2.
}
\keyword{}

\eof
\name{UniNormParameter-class}
\docType{class}
\alias{UniNormParameter-class}
\alias{initialize,UniNormParameter-method}
\title{Class "UniNormParameter"}
\description{ The parameter of a univariate normal distribution, used by Norm-class}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("NormParameter", sd, mean)}.
  Usually an object of this class is not needed on its own, it is
  generated automatically when an object of the class Norm is
  instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{sd}:}{Object of class \code{"numeric"}:
      the sd of a univariate normal distribution}
    \item{\code{mean}:}{Object of class \code{"numeric"}:
      the mean of a univariate normal distribution}
    \item{\code{name}:}{Object of class \code{"character"}:
      a name / comment for the parameters}
  }
}
\section{Extends}{
Class \code{"NormParameter"}, directly.
Class \code{"Parameter"}, by class \code{"NormParameter"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "UniNormParameter")}:
      initialize method}
    \item{mean}{\code{signature(object = "UniNormParameter")}:
      returns the slot mean of the parameter of the distribution}
    \item{mean<-}{\code{signature(object = "UniNormParameter")}:
      modifies the slot mean of the parameter of the distribution}
    \item{sd}{\code{signature(object = "UniNormParameter")}:
      returns the slot sd of the parameter of the distribution}
    \item{sd<-}{\code{signature(object = "UniNormParameter")}:
      modifies the slot sd of the parameter of the distribution}
  }
}

\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Norm-class}}
\code{\link{NormParameter-class}}
\code{\link{Parameter-class}}
}
\examples{
W <- new("UniNormParameter", mean = 0, sd = 1)
sd(W) # sd of this distribution is 1
sd(W) <- 2 # sd of this distribution is now 2
}
\keyword{}

\eof
\name{Unif-class}
\docType{class}
\alias{Unif-class}
\alias{Unif}
\alias{initialize,Unif-method}

\title{Class "Unif"}
\description{ 
  The uniform distribution has density
  \deqn{d(x) = \frac{1}{max-min}}{d(x) = 1/(max-min)}
  for \eqn{min}, by default \eqn{=0}, \eqn{\le x \le max}, by default \eqn{=1}.
C.f. \code{\link{runif}} 
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Unif(Min, Max)}.
This object is a uniform distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"UnifParameter"}: the parameter of this distribution (Min and Max),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{runif})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dunif})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{punif})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qunif})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Unif")}: initialize method }
    \item{Min}{\code{signature(object = "Unif")}: returns the slot \code{Min} of the parameter of the distribution }
    \item{Min<-}{\code{signature(object = "Unif")}: modifies the slot \code{Min} of the parameter of the distribution }
    \item{Max}{\code{signature(object = "Unif")}: returns the slot \code{Max} of the parameter of the distribution }
    \item{Max<-}{\code{signature(object = "Unif")}: modifies the slot \code{Max} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{UnifParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{runif}}

}
\examples{
U=Unif(Min=0,Max=2) # U is a uniform distribution with Min=0 and Max=2.
r(U)(1) # one random number generated from this distribution, e.g. 1.984357
d(U)(1) # Density of this distribution is 0.5 for x=1.
p(U)(1) # Probability that x<1 is 0.5.
q(U)(.1) # Probability that x<0.2 is 0.1.
Min(U) # Min of this distribution is 0.
Min(U)=1 # Min of this distribution is now 1.
}
\keyword{}

\eof
\name{UnifParameter-class}
\docType{class}
\alias{UnifParameter-class}
\alias{initialize,UnifParameter-method}

\title{Class "UnifParameter"}
\description{ The parameter of a uniform distribution, used by Unif-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("UnifParameter", Max, Min)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class 
\code{Unif} is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{Max}:}{Object of class \code{"numeric"}: the Max of a uniform distribution }
    \item{\code{Min}:}{Object of class \code{"numeric"}: the Min of a uniform distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "UnifParameter")}: initialize method }
    \item{Min}{\code{signature(object = "UnifParameter")}: returns the slot \code{Min} of the parameter of the distribution }
    \item{Min<-}{\code{signature(object = "UnifParameter")}: modifies the slot \code{Min} of the parameter of the distribution }
    \item{Max}{\code{signature(object = "UnifParameter")}: returns the slot \code{Max} of the parameter of the distribution }
    \item{Max<-}{\code{signature(object = "UnifParameter")}: modifies the slot \code{Max} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Unif-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("UnifParameter",Min=0,Max=1)
Max(W) # Max of this distribution is 1.
Max(W)=2 # Max of this distribution is now 2.
}
\keyword{}

\eof
\name{UnivariateDistribution-class}
\docType{class}
\alias{UnivariateDistribution-class}
\alias{initialize,UnivariateDistribution-method}
\title{Class "UnivariateDistribution"}
\description{
  The UnivariateDistribution-class is the mother-class of the classes
  AbscontDistribution and DiscreteDistribution.
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("UnivariateDistribution")}.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}:
      the space of the image of this distribution which has dimension 1
      and the name "Real Space"} 
    \item{\code{param}:}{Object of class \code{"Parameter"}:
      the parameter of this distribution}
    \item{\code{r}:}{Object of class \code{"function"}:
      generates random numbers}
    \item{\code{d}:}{Object of class \code{"function"}:
      density function}
    \item{\code{p}:}{Object of class \code{"function"}:
      cumulative distribution function}
    \item{\code{q}:}{Object of class \code{"function"}:
      quantile function}
  }
}
\section{Extends}{
Class \code{"Distribution"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object =	"UnivariateDistribution")}:

      initialize method }
    \item{-}{\code{signature(e1 = "UnivariateDistribution")}:

      application of `-' to this univariate distribution}
    \item{*}{\code{signature(e1 = "UnivariateDistribution", e2 = "numeric")}:

      multiplication of this univariate distribution by an object of
      class `numeric'} 
    \item{/}{\code{signature(e1 = "UnivariateDistribution", e2 = "numeric")}:

      division of this univariate distribution by an object of class `numeric'}
    \item{+}{\code{signature(e1 = "UnivariateDistribution", e2 = "numeric")}:

      addition of this univariate distribution to an object of class
      `numeric'} 
    \item{-}{\code{signature(e1 = "UnivariateDistribution", e2 = "numeric")}:

      subtraction of an object of class `numeric' from this univariate
      distribution} 
    \item{*}{\code{signature(e1 = "numeric", e2 = "UnivariateDistribution")}:

      multiplication of this univariate distribution by an object of
      class `numeric'} 
    \item{+}{\code{signature(e1 = "numeric", e2 = "UnivariateDistribution")}:

      addition of this univariate distribution to an object of class
      `numeric'} 
    \item{-}{\code{signature(e1 = "numeric", e2 = "UnivariateDistribution")}:

      subtraction of this univariate distribution from an object of
      class `numeric'}
    \item{+}{\code{signature(e1 = "UnivariateDistribution", e2 = "UnivariateDistribution")}:

      Convolution of two univariate distributions. The slots p, d and q
      are approximated by grids.}
    \item{-}{\code{signature(e1 = "UnivariateDistribution", e2 = "UnivariateDistribution")}:
      
      Convolution of two univariate distributions. The slots p, d and q
      are approximated by grids.}
    \item{simplifyr}{\code{signature(object = "UnivariateDistribution")}:

      simplifies the r-method of a distribution, see there for further information}
    \item{print}{\code{signature(object = "UnivariateDistribution")}:

      returns the class of the object and its parameters}
  }
}


\author{
  Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr
  Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
  Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr
  Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}
}
\seealso{
\code{\link{Parameter-class}}
\code{\link{Distribution-class}}
\code{\link{AbscontDistribution-class}} \cr
\code{\link{DiscreteDistribution-class}} 
\code{\link{Reals-class}} 
\code{\link{RtoDPQ}}
\code{\link{simplifyr-methods}}
}
\keyword{}

\eof
\name{Weibull-class}
\docType{class}
\alias{Weibull-class}
\alias{Weibull}
\alias{initialize,Weibull-method}

\title{Class "Weibull"}
\description{  The Weibull distribution with \code{shape} parameter \eqn{a}, by default \eqn{=1}, and
  \code{scale} parameter \eqn{\sigma}{b} has density given by, by default \eqn{=1},
  \deqn{d(x) = (a/\sigma) {(x/\sigma)}^{a-1} \exp (-{(x/\sigma)}^{a})}{%
        d(x) = (a/b) (x/b)^(a-1) exp(- (x/b)^a)}
  for \eqn{x > 0}.

C.f. \code{\link{rweibull}}
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{Weibull(shape, scale)}.
This object is a Weibull distribution.
}
\section{Slots}{
  \describe{
    \item{\code{img}:}{Object of class \code{"Reals"}: The space of the image of this distribution has got dimension 1
    and the name "Real Space". }
    \item{\code{param}:}{Object of class \code{"WeibullParameter"}: the parameter of this distribution (shape and scale),
     declared at its instantiation }
    \item{\code{r}:}{Object of class \code{"function"}: generates random numbers (calls function \code{rweibull})}
    \item{\code{d}:}{Object of class \code{"function"}: density function (calls function \code{dweibull})}
    \item{\code{p}:}{Object of class \code{"function"}: cumulative function (calls function \code{pweibull})}
    \item{\code{q}:}{Object of class \code{"function"}: inverse of the cumulative function (calls function \code{qweibull})}
  }
}
\section{Extends}{
Class \code{"AbscontDistribution"}, directly.\cr
Class \code{"UnivariateDistribution"}, by class \code{"AbscontDistribution"}.\cr
Class \code{"Distribution"}, by class \code{"AbscontDistribution"}.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "Weibull")}: initialize method }
    \item{scale}{\code{signature(object = "Weibull")}: returns the slot \code{scale} of the parameter of the distribution }
    \item{scale<-}{\code{signature(object = "Weibull")}: modifies the slot \code{scale} of the parameter of the distribution }
    \item{shape}{\code{signature(object = "Weibull")}: returns the slot \code{shape} of the parameter of the distribution }
    \item{shape<-}{\code{signature(object = "Weibull")}: modifies the slot \code{shape} of the parameter of the distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{ The density is \eqn{d(x)=0} for \eqn{x < 0}.\cr
The cumulative is
  \eqn{p(x) = 1 - \exp(-{(x/\sigma)}^a)}{p(x) = 1 - exp(- (x/b)^a)},\cr
  the mean is \eqn{E(X) = \sigma \Gamma(1 + 1/a)}{E(X) = b Gamma(1 + 1/a)},\cr
  and the \eqn{Var(X) = \sigma^2(\Gamma(1 + 2/a)-(\Gamma(1 + 1/a))^2)}{%
           Var(X) = b^2 * (gamma(1 + 2/a) - (gamma(1 + 1/a))^2)}.

}

\seealso{
\code{\link{WeibullParameter-class}}
\code{\link{AbscontDistribution-class}}
\code{\link{Reals-class}}
\code{\link{rweibull}}





}
\examples{
W=Weibull(shape=1,scale=1) # W is a Weibull distribution with shape=1 and scale=1.
r(W)(1) # one random number generated from this distribution, e.g. 0.5204105
d(W)(1) # Density of this distribution is 0.3678794 for x=1.
p(W)(1) # Probability that x<1 is 0.6321206.
q(W)(.1) # Probability that x<0.1053605 is 0.1.
shape(W) # shape of this distribution is 1.
shape(W)=2 # shape of this distribution is now 2.
}
\keyword{}

\eof
\name{WeibullParameter-class}
\docType{class}
\alias{WeibullParameter-class}
\alias{initialize,WeibullParameter-method}

\title{Class "WeibullParameter"}
\description{ The parameter of a Weibull distribution, used by \code{Weibull}-class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("WeibullParameter", shape, scale)}.
Usually an object of this class is not needed on its own, it is generated automatically when an object of the class \code{Weibull}
is instantiated. 
}
\section{Slots}{
  \describe{
    \item{\code{shape}:}{Object of class \code{"numeric"}: the shape of a Weibull distribution }
    \item{\code{scale}:}{Object of class \code{"numeric"}: the scale of a Weibull distribution }
    \item{\code{name}:}{Object of class \code{"character"}: a name / comment for the parameters }
  }
}
\section{Extends}{
Class \code{"Parameter"}, directly.
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "WeibullParameter")}: initialize method }
    \item{scale}{\code{signature(object = "WeibullParameter")}: returns the slot \code{scale} of a parameter of a Weibull
    distribution }
    \item{scale<-}{\code{signature(object = "WeibullParameter")}: modifies the slot \code{scale} of a parameter of a Weibull
    distribution }
    \item{shape}{\code{signature(object = "WeibullParameter")}: returns the slot \code{shape} of a parameter of a Weibull
    distribution }
    \item{shape<-}{\code{signature(object = "WeibullParameter")}: modifies the slot \code{shape} of a parameter of a Weibull
    distribution }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\seealso{
\code{\link{Weibull-class}}
\code{\link{Parameter-class}}
}

\examples{
W=new("WeibullParameter",shape=1,scale=1)
shape(W) # shape of this distribution is 1.
shape(W)=2 # shape of this distribution is now 2.
}
\keyword{}

\eof
\name{call.ev-methods}
\docType{methods}
\alias{call.ev-methods}
\alias{call.ev}
\alias{call.ev,Evaluation-method}
\title{ Methods for Function call.ev in Package `distr' }
\description{call.ev-methods}
\section{Methods}{\describe{
    \item{call.ev}{\code{signature(object = "Evaluation")}: returns the call which created the object }
}}
\keyword{}

\eof
\name{cload}
\alias{cload}
\title{ cload }
\description{
loads the comment file from a saved \code{Dataclass} or \code{Evaluation} object
}
\usage{
cload(filename)
}
\arguments{
  \item{filename}{ the filename which was declared at the instantiaton of the Dataclass }
}
\details{}
\value{ no value is returned }
\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\seealso{
\code{\link{Evaluation-class}}
\code{\link{Dataclass-class}}
\code{\link{load}}
\code{\link{savedata-methods}}
}

\examples{
# see Dataclass and Evaluation for examples
## The function is currently defined as
function(filename){
  eval.parent(parse(text=paste("load(\"",filename,".comment\")", sep = "")))
  }
}
\keyword{}

\eof
\name{d-methods}
\docType{methods}
\alias{d-methods}
\alias{d}
\alias{d,Distribution-method}
\title{ Methods for Function d in Package `distr' }
\description{d-methods}

\section{Methods}{\describe{

\item{d}{\code{signature(object = "Distribution")}: returns the density function }
}}
\keyword{}

\eof
\name{df-methods}
\docType{methods}
\alias{df-methods}
\alias{df<--methods}
\alias{df}
\alias{df<-}
\alias{df,TParameter-method}
\alias{df,Td-method}
\alias{df,ChisqParameter-method}
\alias{df,Chisq-method}
\alias{df<-,TParameter-method}
\alias{df<-,Td-method}
\alias{df<-,ChisqParameter-method}
\alias{df<-,Chisq-method}
\title{ Methods for Function df in Package `distr' }
\description{df-methods}

\section{Methods}{\describe{

\item{df}{\code{signature(object = "TParameter")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "TParameter")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "Td")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "Td")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "ChisqParameter")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "Chisq")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "Chisq")}: modifies the slot \code{df} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{df1-methods}
\docType{methods}
\alias{df1-methods}
\alias{df1<--methods}
\alias{df1}
\alias{df1<-}
\alias{df1,FParameter-method}
\alias{df1,Fd-method}
\alias{df1<-,FParameter-method}
\alias{df1<-,Fd-method}
\title{ Methods for Function df1 in Package `distr' }
\description{df-methods}

\section{Methods}{\describe{

\item{df1}{\code{signature(object = "FParameter")}: returns the slot \code{df1} of the parameter of an F-distribution }
\item{df1<-}{\code{signature(object = "FParameter")}: modifies the slot \code{df1} of the parameter of an F-distribution }

\item{df1}{\code{signature(object  = "Fd")}: returns the slot \code{df1} of the slot \code{param} of the distribution}
\item{df1<-}{\code{signature(object = "Fd")}: modifies the slot \code{df1} of the slot \code{param} of the distribution }
}}
\keyword{}

\eof
\name{df2-methods}
\docType{methods}
\alias{df2-methods}
\alias{df2<--methods}
\alias{df2}
\alias{df2<-}
\alias{df2,FParameter-method}
\alias{df2,Fd-method}
\alias{df2<-,FParameter-method}
\alias{df2<-,Fd-method}
\title{ Methods for Function df2 in Package `distr' }
\description{df-methods}

\section{Methods}{\describe{

\item{df2}{\code{signature(object = "FParameter")}: returns the slot \code{df2} of the parameter of an F-distribution }
\item{df2<-}{\code{signature(object = "FParameter")}: modifies the slot \code{df2} of the parameter of an F-distribution }

\item{df2}{\code{signature(object  = "Fd")}: returns the slot \code{df2} of the slot \code{param} of the distribution}
\item{df2<-}{\code{signature(object = "Fd")}: modifies the slot \code{df2} of the slot \code{param} of the distribution }
}}
\keyword{}

\eof
\name{dimension-methods}
\docType{methods}
\alias{dimension-methods}
\alias{dimension<--methods}
\alias{dimension}
\alias{dimension<-}
\alias{dimension,EuclideanSpace-method}
\alias{dimension<-,EuclideanSpace-method}

\title{ Methods for Function dimension in Package `distr' }
\description{dimension-methods}
\section{Methods}{\describe{
    \item{dimension}{\code{signature(object = "EuclideanSpace")}: returns the dimension of the space }
    \item{dimension<-}{\code{signature(object = "EuclideanSpace")}: modifies the dimension of the space }
}}
\keyword{}

\eof
\name{distribution-methods}
\docType{methods}
\alias{distribution-methods}
\alias{distribution<--methods}
\alias{distribution}
\alias{distribution<-}
\alias{distribution,Simulation-method}
\alias{distribution<-,Simulation-method}
\title{ Methods for Function distribution in Package `distr' }
\description{distribution-methods}

\section{Methods}{\describe{

\item{distribution}{\code{signature(object = "Simulation")}: returns the slot \code{distribution} of the simulation}
\item{distribution<-}{\code{signature(object = "Simulation")}: changes the slot \code{distribution} of the simulation}
}}
\keyword{}

\eof
\name{distribution.c-methods}
\docType{methods}
\alias{distribution.c-methods}
\alias{distribution.c<--methods}
\alias{distribution.c}
\alias{distribution.c<-}
\alias{distribution.c,Contsimulation-method}
\alias{distribution.c<-,Contsimulation-method}
\title{ Methods for Function distribution.c in Package `distr' }
\description{distribution-methods}

\section{Methods}{\describe{

\item{distribution.c}{\code{signature(object = "Contsimulation")}: returns the distribution of the contaminated data}
\item{distribution.c<-}{\code{signature(object = "Contsimulation")}: changes the distribution of the contaminated data}
}}
\keyword{}

\eof
\name{distribution.id-methods}
\docType{methods}
\alias{distribution.id-methods}
\alias{distribution.id<--methods}
\alias{distribution.id}
\alias{distribution.id<-}
\alias{distribution.id,Contsimulation-method}
\alias{distribution.id<-,Contsimulation-method}
\title{ Methods for Function distribution.id in Package `distr' }
\description{distribution-methods}
\section{Methods}{\describe{
\item{distribution.id}{\code{signature(object = "Contsimulation")}: returns the distribution of the ideal data }
\item{distribution.id<-}{\code{signature(object = "Contsimulation")}: changes the distribution of the ideal data}
}}
\keyword{}

\eof
\name{distroptions}
\alias{distroptions}
\alias{DefaultNrGridPoints}
\alias{DistrResolution}
\alias{TruncQuantile}
\alias{DefaultNrFFTGridPointsExponent}
\alias{RtoDPQ.e}

\title{function to change the global variables of the package `distr' }
\description{With \code{distroptions} you may inspect and change the global variables used by the package \pkg{`distr'} }
\usage{
distroptions(arg = "missing", value = -1)
}
\arguments{
  \item{arg}{ the global variable to be shown or changed }
  \item{value}{ the new value of the global variable }
}
\value{
\code{distroptions()} returns a list of the global variables.
\code{distroptions(arg=x)} returns  the global variable \var{x}.
\code{distroptions(arg=x,value=y)} sets the value of the global variable \var{x} to \var{y}.

}
\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}

\examples{
distroptions("RtoDPQ.e") # returns the value of RtoDPQ.e, by default = 5
distroptions("RtoDPQ.e",6) # now RtoDPQ.e = 6

## The function is currently defined as
function (arg = "missing", value = -1) 
{
    globals <- list(DefaultNrFFTGridPointsExponent = DefaultNrFFTGridPointsExponent, 
        DefaultNrGridPoints = DefaultNrGridPoints, DistrResolution = DistrResolution, 
        RtoDPQ.e = RtoDPQ.e, TruncQuantile = TruncQuantile)
    if (arg == "missing") {
        print(globals)
        return(invisible())
    }
    if (!any(arg == names(globals))) 
        stop(paste("No such variable:", arg))
    if (value == -1) 
        switch(arg, DefaultNrGridPoints = DefaultNrGridPoints, 
            DistrResolution = DistrResolution, TruncQuantile = TruncQuantile, 
            DefaultNrFFTGridPointsExponent = DefaultNrFFTGridPointsExponent, 
            RtoDPQ.e = RtoDPQ.e)
    else eval.parent(parse(text = paste("assignInNamespace(\"", 
        arg, "\",", value, ", \"distr\")", sep = "")))
  }
}
\keyword{}

\eof
\name{estimator-methods}
\docType{methods}
\alias{estimator-methods}
\alias{estimator}
\alias{estimator,Evaluation-method}

\title{ Methods for Function estimator in Package `distr'}
\description{estimator-methods}
\section{Methods}{\describe{

\item{estimator}{\code{signature(object = "Evaluation")}: returns the estimator }
}}
\keyword{}

\eof
\name{evaluate-methods}
\docType{methods}
\alias{evaluate-methods}
\alias{evaluate}
\alias{evaluate,Dataclass,function-method}
\title{ Methods for Function evaluate in Package `distr'}
\description{evaluate-methods}
\section{Methods}{\describe{
    \item{evaluate}{\code{signature(object = "Dataclass", estimator = "function")}:

      creates an object of type "Evaluation", see there for further
      information}}}
\seealso{\code{\link{Evaluation-class}}}
\keyword{}

\eof
\name{filename-methods}
\docType{methods}
\alias{filename-methods}
\alias{filename<--methods}
\alias{filename}
\alias{filename<-}
\alias{filename,Dataclass-method}
\alias{filename<-,Dataclass-method}
\alias{filename,Evaluation-method}

\title{ Methods for Function filename in Package `distr' }
\description{filename-methods}
\section{Methods}{\describe{

\item{filename}{\code{signature(object = "Dataclass")}: returns the filename }

\item{filename<-}{\code{signature(object = "Dataclass")}: changes the filename }
    
\item{filename}{\code{signature(object = "Evaluation")}: returns the filename of the evaluated object }
}}
\keyword{}

\eof
\name{img-methods}
\docType{methods}
\alias{img-methods}
\alias{img}
\alias{img,Distribution-method}
\title{ Methods for Function img in Package `distr'}
\description{img-methods}

\section{Methods}{\describe{

\item{img}{\code{signature(object  = "Distribution")}: returns the image space / domain of the distribution }
}}
\keyword{}

\eof
\name{ind-methods}
\docType{methods}
\alias{ind-methods}
\alias{ind}
\alias{ind,Contsimulation-method}
\title{ Methods for Function ind in Package `distr'}
\description{ind-methods}

\section{Methods}{\describe{

\item{ind}{\code{signature(object = "Contsimulation")}: returns an indicator showing which data is contaminated }
}}
\keyword{}

\eof
\name{k-methods}
\docType{methods}
\alias{k-methods}
\alias{k<--methods}
\alias{k}
\alias{k<-}
\alias{k,HyperParameter-method}
\alias{k,Hyper-method}
\alias{k<-,HyperParameter-method}
\alias{k<-,Hyper-method}
\title{ Methods for Function k in Package `distr' }
\description{k-methods}

\section{Methods}{\describe{

\item{k}{\code{signature(object = "HyperParameter")}: returns the slot \code{k} of the parameter of the distribution }
\item{k<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{k} of the parameter of the distribution }

\item{k}{\code{signature(object = "Hyper")}: returns the slot \code{k} of the parameter of the distribution }
\item{k<-}{\code{signature(object = "Hyper")}: modifies the slot \code{k} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{lambda-methods}
\docType{methods}
\alias{lambda-methods}
\alias{lambda<--methods}
\alias{lambda}
\alias{lambda<-}
\alias{lambda,PoisParameter-method}
\alias{lambda,Pois-method}
\alias{lambda<-,PoisParameter-method}
\alias{lambda<-,Pois-method}
\title{ Methods for Function lambda  in Package `distr'}
\description{lambda-methods}

\section{Methods}{\describe{

\item{lambda}{\code{signature(object = "PoisParameter")}: returns the slot \code{lambda} of the parameter of the distribution }
\item{lambda<-}{\code{signature(object = "PoisParameter")}: modifies the slot \code{lambda} of the parameter of the distribution }

\item{lambda}{\code{signature(object  = "Pois")}: returns the slot \code{lambda} of the parameter of the distribution }
\item{lambda<-}{\code{signature(object = "Pois")}: modifies the slot \code{lambda} of the parameter of the distribution }

}}
\keyword{}

\eof
\name{liesIn-methods}
\docType{methods}
\alias{liesIn-methods}
\alias{liesIn}
\alias{liesIn,EuclideanSpace,numeric-method}
\alias{liesIn,Naturals,numeric-method}
\title{ Methods for Function liesIn in Package `distr' }
\description{liesIn-methods}
\section{Methods}{\describe{
    \item{liesIn}{\code{signature(object = "EuclideanSpace", x =
	"numeric")}}:
    
    Does a particular vector lie in this space or not?
    \item{liesIn}{\code{signature(object = "Naturals", x =
	"numeric")}}:
    
    Does a particular vector only contain naturals?}
  }}
\keyword{}

\eof
\name{location-methods}
\docType{methods}
\alias{location-methods}
\alias{location<--methods}
\alias{location}
\alias{location<-}
\alias{location,LogisParameter-method}
\alias{location,Logis-method}
\alias{location,CauchyParameter-method}
\alias{location,Cauchy-method}
\alias{location,DiracParameter-method}
\alias{location,Dirac-method}
\alias{location<-,LogisParameter-method}
\alias{location<-,Logis-method}
\alias{location<-,CauchyParameter-method}
\alias{location<-,Cauchy-method}
\alias{location<-,DiracParameter-method}
\alias{location<-,Dirac-method}
\title{ Methods for Function location in Package `distr' }
\description{location-methods}

\section{Methods}{\describe{

\item{location}{\code{signature(object = "LogisParameter")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "LogisParameter")}: modifies the slot \code{location} of the parameter of the
distribution }

\item{location}{\code{signature(object = "Logis")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "Logis")}: modifies the slot \code{location} of the parameter of the distribution }

\item{location}{\code{signature(object = "CauchyParameter")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "CauchyParameter")}: modifies the slot \code{location} of the parameter of the
distribution }

\item{location}{\code{signature(object = "Cauchy")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "Cauchy")}: modifies the slot \code{location} of the parameter of the distribution }

\item{location}{\code{signature(object = "DiracParameter")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "DiracParameter")}: modifies the slot \code{location} of the parameter of the
distribution}

\item{location}{\code{signature(object = "Dirac")}: returns the slot \code{location} of the parameter of the distribution }
\item{location<-}{\code{signature(object = "Dirac")}: modifies the slot \code{location} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{m-methods}
\docType{methods}
\alias{m-methods}
\alias{m<--methods}
\alias{m}
\alias{m<-}
\alias{m,HyperParameter-method}
\alias{m,Hyper-method}
\alias{m<-,HyperParameter-method}
\alias{m<-,Hyper-method}
\title{ Methods for Function m in Package `distr' }
\description{m-methods}
\section{Methods}{\describe{
\item{m}{\code{signature(object = "HyperParameter")}: returns the slot m of the parameter of the distribution }
\item{m<-}{\code{signature(object = "HyperParameter")}: modifies the slot m of the parameter of the distribution }
\item{m}{\code{signature(object = "Hyper")}: returns the slot m of the parameter of the distribution }
\item{m<-}{\code{signature(object = "Hyper")}: modifies the slot m of the parameter of the distribution }
}}
\keyword{}

\eof
\name{mean-methods}
\docType{methods}
\alias{mean-methods}
\alias{mean<--methods}
\alias{mean}
\alias{mean<-}
\alias{mean,NormParameter-method}
\alias{mean,Norm-method}
\alias{mean<-,NormParameter-method}
\alias{mean<-,Norm-method}
\title{ Methods for Function mean in Package `distr' }
\description{mean-methods}
\section{Methods}{\describe{
\item{mean}{\code{signature(object = "NormParameter")}: returns the slot mean of the parameter of the distribution }    
\item{mean<-}{\code{signature(object = "NormParameter")}: modifies the slot mean of the parameter of the distribution }
\item{mean}{\code{signature(object = "Norm")}: returns the slot mean of the parameter of the distribution }
\item{mean<-}{\code{signature(object = "Norm")}: modifies the slot mean of the parameter of the distribution }
}}
\keyword{}

\eof
\name{meanlog-methods}
\docType{methods}
\alias{meanlog-methods}
\alias{meanlog<--methods}
\alias{meanlog}
\alias{meanlog<-}
\alias{meanlog,LnormParameter-method}
\alias{meanlog,Lnorm-method}
\alias{meanlog<-,LnormParameter-method}
\alias{meanlog<-,Lnorm-method}
\title{ Methods for Function meanlog in Package `distr' }
\description{meanlog-methods}
\section{Methods}{\describe{
\item{meanlog}{\code{signature(object = "LnormParameter")}: returns the slot meanlog of the parameter of the distribution }
\item{meanlog<-}{\code{signature(object = "LnormParameter")}: modifies the slot meanlog of the parameter of the distribution }
\item{meanlog}{\code{signature(object = "Lnorm")}: returns the slot meanlog of the parameter of the distribution }
\item{meanlog<-}{\code{signature(object = "Lnorm")}: modifies the slot meanlog of the parameter of the distribution }
}}
\keyword{}

\eof
\name{n-methods}
\docType{methods}
\alias{n-methods}
\alias{n<--methods}
\alias{n}
\alias{n<-}
\alias{n,HyperParameter-method}
\alias{n,Hyper-method}
\alias{n<-,HyperParameter-method}
\alias{n<-,Hyper-method}
\title{ Methods for Function n in Package `distr' }
\description{n-methods}

\section{Methods}{\describe{

\item{n}{\code{signature(object = "HyperParameter")}: returns the slot \code{n} of the parameter of the distribution }
\item{n<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{n} of the parameter of the distribution }

\item{n}{\code{signature(object = "Hyper")}: returns the slot \code{n} of the parameter of the distribution }
\item{n<-}{\code{signature(object = "Hyper")}: modifies the slot \code{n} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{name-methods}
\docType{methods}
\alias{name-methods}
\alias{name<--methods}
\alias{name}
\alias{name<-}
\alias{name,Parameter-method}
\alias{name<-,Parameter-method}
\alias{name,rSpace-method}
\alias{name<-,rSpace-method}
\alias{name,Evaluation-method}
\title{ Methods for Function name in Package `distr' }
\description{name-methods}
\section{Methods}{\describe{
\item{name}{\code{signature(object = "Parameter")}: returns the slot name of the parameter }
\item{name<-}{\code{signature(object = "Parameter")}: modifies the slot name of the parameter }
\item{name}{\code{signature(object = "rSpace")}: returns the slot name of the space }
\item{name<-}{\code{signature(object = "rSpace")}: modifies the slot name of the space }
\item{name}{\code{signature(object = "Evaluation")}: returns the slot name of data object }
}}
\keyword{}

\eof
\name{ncp-methods}
\docType{methods}
\alias{ncp-methods}
\alias{ncp<--methods}
\alias{ncp}
\alias{ncp<-}
\alias{ncp,ChisqParameter-method}
\alias{ncp,Chisq-method}
\alias{ncp<-,ChisqParameter-method}
\alias{ncp<-,Chisq-method}
\title{ Methods for Function ncp in Package `distr' }
\description{ncp-methods}

\section{Methods}{\describe{

\item{ncp}{\code{signature(object = "ChisqParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "Chisq")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "Chisq")}: modifies the slot \code{ncp} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{operators-methods}
\docType{methods}

\alias{-,numeric,UnivariateDistribution-method}
\alias{-,UnivariateDistribution,UnivariateDistribution-method}
\alias{-,UnivariateDistribution,ANY-method}
\alias{*,Exp,numeric-method}
\alias{*,numeric,UnivariateDistribution-method}
\alias{*,Gamma,numeric-method}
\alias{+,AbscontDistribution,AbscontDistribution-method}
\alias{+,DiscreteDistribution,AbscontDistribution-method}
\alias{+,Chisq,Chisq-method}
\alias{+,Exp,Exp-method}
\alias{+,numeric,UnivariateDistribution-method}
\alias{+,Gamma,Gamma-method}
\alias{+,Nbinom,Nbinom-method}



\alias{operators-methods}
\alias{-,UnivariateDistribution}
\alias{*,UnivariateDistribution,numeric-method}
\alias{/,UnivariateDistribution,numeric-method}
\alias{+,UnivariateDistribution,numeric-method}
\alias{-,UnivariateDistribution,numeric-method}
\alias{*,numeric-method,UnivariateDistribution}
\alias{+,numeric-method,UnivariateDistribution}
\alias{-,numeric-method,UnivariateDistribution}
\alias{+,UnivariateDistribution,DiscreteDistribution-method}
\alias{-,UnivariateDistribution,DiscreteDistribution-method}
\alias{-,AbscontDistribution}
\alias{*,AbscontDistribution,numeric-method}
\alias{/,AbscontDistribution,numeric-method}
\alias{+,AbscontDistribution,numeric-method}
\alias{-,AbscontDistribution,numeric-method}
\alias{*,numeric-method,AbscontDistribution}
\alias{+,numeric-method,AbscontDistribution}
\alias{-,numeric-method,AbscontDistribution}
\alias{+,AbscontDistribution,DiscreteDistribution-method}
\alias{-,AbscontDistribution,DiscreteDistribution-method}
\alias{-,DiscreteDistribution}
\alias{*,DiscreteDistribution,numeric-method}
\alias{/,DiscreteDistribution,numeric-method}
\alias{+,DiscreteDistribution,numeric-method}
\alias{-,DiscreteDistribution,numeric-method}
\alias{*,numeric-method,DiscreteDistribution}
\alias{+,numeric-method,DiscreteDistribution}
\alias{-,numeric-method,DiscreteDistribution}
\alias{+,DiscreteDistribution,DiscreteDistribution-method}
\alias{-,DiscreteDistribution,DiscreteDistribution-method}
\alias{-,Norm,Norm-method}
\alias{+,Norm,Norm-method}
\alias{+,numeric,Norm-method}
\alias{*,numeric,Norm-method}
\alias{-,numeric,Norm-method}
\alias{+,Norm,numeric-method}
\alias{*,Norm,numeric-method}
\alias{-,Norm,numeric-method}
\alias{/,Norm,numeric-method}
\alias{+,Binom,Binom-method}
\alias{+,Pois,Pois-method}
\title{ Methods for operators +,-,*,/ in Package `distr' }
\description{operator-methods}
\section{Methods}{\describe{

    \item{-}{\code{signature(e1 = "UnivariateDistribution")}:

      application of `-' to this univariate distribution}
    \item{*}{\code{signature(e1 = "UnivariateDistribution", e2 =
	"numeric")}:

      multiplication of this univariate 
    distribution by an object of class `numeric'}
  \item{/}{\code{signature(e1 = "UnivariateDistribution", e2 =
      "numeric")}:

    division of this univariate distribution
    by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "UnivariateDistribution", e2 =
      "numeric")}:

    addition of this univariate distribution
    to an object of class `numeric'}
  \item{-}{\code{signature(e1 = "UnivariateDistribution", e2 =
      "numeric")}:

    subtraction of an object of class `numeric'
    from this univariate distribution }
  \item{*}{\code{signature(e1 = "numeric", e2 =
      "UnivariateDistribution")}:

    multiplication of this univariate
    distribution by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "numeric", e2 =
      "UnivariateDistribution")}:

    addition of this univariate distribution to
    an object of class `numeric'}
  \item{-}{\code{signature(e1 = "numeric", e2 =
      "UnivariateDistribution")}:

    subtraction of this univariate distribution
    from an object of class `numeric'}
  \item{+}{\code{signature(e1 = "UnivariateDistribution", e2 =
      "UnivariateDistribution")}:

    Convolution of two univariate
    distributions. The slots p, d and q are approximated by grids.}
  \item{-}{\code{signature(e1 = "UnivariateDistribution", e2 =
      "UnivariateDistribution")}:

    Convolution of two univariate
    distributions. The slots p, d and q are approximated by grids.}
  \item{-}{\code{signature(e1 = "AbscontDistribution")}:

    application of `-' to this absolutely continuous distribution}
  \item{*}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}:

    multiplication of this absolutely continuous 
    distribution by an object of class `numeric'}
  \item{/}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}:

    division of this absolutely continuous 
    distribution by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}:

    addition of this absolutely continuous 
    distribution to an object of class `numeric'}
  \item{-}{\code{signature(e1 = "AbscontDistribution", e2 = "numeric")}:

    subtraction of an object of class `numeric' from
    this absolutely continuous distribution }
  \item{*}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}:

    multiplication of this absolutely continuous 
    distribution by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}:

    addition of this absolutely continuous 
    distribution to an object of class `numeric'}
  \item{-}{\code{signature(e1 = "numeric", e2 = "AbscontDistribution")}:

    subtraction of this absolutely continuous 
    distribution from an object of class `numeric'}
  \item{+}{\code{signature(e1 = "AbscontDistribution", e2 =
      "AbscontDistribution")}:

    Convolution of two absolutely
    continuous distributions. The slots p, d and q are approximated by grids.}
  \item{-}{\code{signature(e1 = "AbscontDistribution", e2 =
      "AbscontDistribution")}:

    Convolution of two absolutely
    continuous distributions. The slots p, d and q are approximated by grids.}
  \item{-}{\code{signature(e1 = "DiscreteDistribution")}:

    application of `-' to this discrete distribution}
  \item{*}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "numeric")}:

    multiplication of this discrete distribution
    by an object of class `numeric'}
  \item{/}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "numeric")}:

    division of this discrete distribution
    by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "numeric")}:

    addition of this discrete distribution
    to an object of class `numeric'}
  \item{-}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "numeric")}:

    subtraction of an object of class `numeric'
    from this discrete distribution }
  \item{*}{\code{signature(e1 = "numeric", e2 =
      "DiscreteDistribution")}:

    multiplication of this discrete distribution
    by an object of class `numeric'}
  \item{+}{\code{signature(e1 = "numeric", e2 =
      "DiscreteDistribution")}:

    addition of this discrete distribution
    to an object of class `numeric'}
  \item{-}{\code{signature(e1 = "numeric", e2 =
      "DiscreteDistribution")}:

    subtraction of this discrete distribution
    from an object of class `numeric'}
  \item{+}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "DiscreteDistribution")}:

    Convolution of two discrete
    distributions. The slots p, d and q are approximated by grids.}
  \item{-}{\code{signature(e1 = "DiscreteDistribution", e2 =
      "DiscreteDistribution")}:

    Convolution of two discrete
    distributions. The slots p, d and q are approximated by grids.}
  \item{*}{\code{signature(e1 = "numeric", e2 = "Norm")}:

    multiplication of this normal distribution by an object of
    class `numeric'}
  \item{+}{\code{signature(e1 = "numeric", e2 = "Norm")}:

    addition of this normal distribution to an object of class
    `numeric'}
  \item{-}{\code{signature(e1 = "numeric", e2 = "Norm")}:

    subtraction of this normal distribution from an object of
    class `numeric'}
  \item{*}{\code{signature(e1 = "Norm", e2 = "numeric")}:

    multiplication of this normal distribution by an object of
    class `numeric'}
  \item{+}{\code{signature(e1 = "Norm", e2 = "numeric")}:

    addition of this normal distribution to an object of class
    `numeric'}
  \item{-}{\code{signature(e1 = "Norm", e2 = "numeric")}:

    subtraction of an object of class `numeric' from this normal
    distribution }
  \item{/}{\code{signature(e1 = "Norm", e2 = "numeric")}:

    division of this normal distribution by an object of class
    `numeric'}
    \item{-}{\code{signature(e1 = "Norm", e2 = "Norm")}}
    \item{+}{\code{signature(e1 = "Norm", e2 = "Norm")}: 

      For the normal distribution the exact convolution formulas are implemented thereby improving the general numerical
    approximation.}
  \item{+}{\code{signature(e1 = "Binom", e2 = "Binom")}:

    For two binomial distributions with the same probabilities
    the exact convolution formula is implemented thereby improving the general numerical approximation.}
  \item{+}{\code{signature(e1 = "Pois", e2 = "Pois")}:

    For the Poisson distribution the exact convolution formula is
    implemented thereby improving the general numerical approximation.}
}}

\seealso{
\code{\link{UnivariateDistribution-class}}
\code{\link{AbscontDistribution-class}} \cr
\code{\link{DiscreteDistribution-class}}
\code{\link{Norm-class}}
\code{\link{Binom-class}}
\code{\link{Pois-class}}
}


\keyword{}

\eof
\name{p-methods}
\docType{methods}
\alias{p-methods}
\alias{p}
\alias{p,Distribution-method}
\title{ Methods for Function p in Package `distr' }
\description{p-methods}

\section{Methods}{\describe{

\item{p}{\code{signature(object = "Distribution")}: returns the cumulative distribution function }
}}
\keyword{}

\eof
\name{param-methods}
\docType{methods}
\alias{param-methods}
\alias{param}
\alias{param,Distribution-method}
\title{ Methods for Function param in Package `distr' }
\description{param-methods}
\section{Methods}{\describe{
\item{param}{\code{signature(object = "Distribution")}: returns the parameter }
}}
\keyword{}

\eof
\name{plot-methods}
\docType{methods}
\alias{plot-methods}
\alias{plot,AbscontDistribution-method}
\alias{plot,DiscreteDistribution-method}
\alias{plot,Dataclass-method}
\alias{plot,Simulation-method}
\alias{plot,Contsimulation-method}
\alias{plot,Evaluation-method}
\title{ Methods for Function plot in Package `distr' }
\description{plot-methods}
\section{Methods}{\describe{
\item{plot}{\code{signature(object = "AbscontDistribution")}: plots density, cumulative and the inverse of the cumulative function }
\item{plot}{\code{signature(object = "DiscreteDistribution")}: plots density, cumulative and the inverse of the cumulative function }
\item{plot}{\code{signature(object = "Dataclass")}: produces a plot of the data matrix }
\item{plot}{\code{signature(object = "Simulation")}: produces a plot of the data matrix }
\item{plot}{\code{signature(object = "Contsimulation")}: produces a plot of the real data matrix }
\item{plot}{\code{signature(object = "Evaluation")}: returns a boxplot of the result }
}}
\keyword{}

\eof
\name{print-methods}
\docType{methods}
\alias{print-methods}
\alias{print,UnivariateDistribution-method}
\alias{print,Dataclass-method}
\alias{print,Simulation-method}
\alias{print,Contsimulation-method}
\alias{print,Evaluation-method}
\title{ Methods for Function print in Package `distr' }
\description{print-methods}

\section{Methods}{\describe{

\item{print}{\code{signature(x = "UnivariateDistribution")}: returns the class of the object and its parameters }

\item{print}{\code{signature(x = "Dataclass")}: returns filename, number of runs and the size of the sample }

\item{print}{\code{signature(x = "Simulation")}: returns filename, seed, number of runs, the size of the sample and the distribution }

\item{print}{\code{signature(x = "Contsimulation")}: returns filename, seed, number of runs, the size of the sample, the rate and the distributions }

\item{print}{\code{signature(x = "Evaluation")}: returns the name of the data object, its filename, the estimator used and the result }
}}
\keyword{}

\eof
\name{prob-methods}
\docType{methods}
\alias{prob-methods}
\alias{prob<--methods}
\alias{prob}
\alias{prob<-}
\alias{prob,BinomParameter-method}
\alias{prob,Binom-method}
\alias{prob,NbinomParameter-method}
\alias{prob,Nbinom-method}
\alias{prob,GeomParameter-method}
\alias{prob,Geom-method}
\alias{prob<-,BinomParameter-method}
\alias{prob<-,Binom-method}
\alias{prob<-,NbinomParameter-method}
\alias{prob<-,Nbinom-method}
\alias{prob<-,GeomParameter-method}
\alias{prob<-,Geom-method}
\title{ Methods for Function prob in Package `distr' }
\description{prob-methods}

\section{Methods}{\describe{

\item{prob}{\code{signature(object = "BinomParameter")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "BinomParameter")}: modifies the slot \code{prob} of the parameter of the distribution }

\item{prob}{\code{signature(object = "Binom")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "Binom")}: modifies the slot \code{prob} of the parameter of the distribution }

\item{prob}{\code{signature(object = "NbinomParameter")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "NbinomParameter")}: modifies the slot \code{prob} of the parameter of the distribution }

\item{prob}{\code{signature(object = "Nbinom")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "Nbinom")}: modifies the slot \code{prob} of the parameter of the distribution }

\item{prob}{\code{signature(object = "GeomParameter")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "GeomParameter")}: modifies the slot \code{prob} of the parameter of the distribution }

\item{prob}{\code{signature(object = "Geom")}: returns the slot \code{prop} of the parameter of the distribution }
\item{prob<-}{\code{signature(object = "Geom")}: modifies the slot \code{prob} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{q-methods}
\docType{methods}
\alias{q-methods}
\alias{q}
\alias{q,Distribution-method}
\title{ Methods for Function q in Package `distr' }
\description{q-methods}

\section{Methods}{\describe{

\item{q}{\code{signature(object  = "Distribution")}: returns the quantile function }
}}
\keyword{}

\eof
\name{r-methods}
\docType{methods}
\alias{r-methods}
\alias{r}
\alias{r,Distribution-method}
\title{ Methods for Function r in Package `distr' }
\description{r-methods}
\section{Methods}{\describe{
    \item{p}{\code{signature(object = "Distribution")}: returns the cumulative distribution function }
}}
\keyword{}

\eof
\name{rSpace-class}
\docType{class}
\alias{rSpace-class}

\title{Class "rSpace" }
\description{ The distribution-classes contain a slot where the sample space is stored. Typically, discrete random variables
take naturals as values. rSpace is the mother-class of the class EuclideanSpace. }
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Slots}{
  \describe{
    \item{\code{name}:}{Object of class \code{"character"}: the name of the space }
  }
}
\section{Methods}{
  \describe{
    \item{name}{\code{signature(object = "rSpace")}: returns the name of the space }
    \item{name<-}{\code{signature(object = "rSpace")}: changes the name of the space }
  }
}

\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}


\seealso{
\code{\link{EuclideanSpace-class}}
\code{\link{Distribution-class}}
}
\keyword{}

\eof
\name{rate-methods}
\docType{methods}
\alias{rate-methods}
\alias{rate<--methods}
\alias{rate}
\alias{rate<-}
\alias{rate,ExpParameter-method}
\alias{rate,Exp-method}
\alias{rate,Contsimulation-method}
\alias{rate<-,ExpParameter-method}
\alias{rate<-,Exp-method}
\alias{rate<-,Contsimulation-method}
\title{ Methods for Function rate in Package `distr' }
\description{rate-methods}

\section{Methods}{\describe{

\item{rate}{\code{signature(object = "ExpParameter")}: returns the slot \code{rate} of the parameter of the distribution }
\item{rate<-}{\code{signature(object = "ExpParameter")}: modifies the slot \code{rate} of the parameter of the distribution }

\item{rate}{\code{signature(object = "Exp")}: returns the slot \code{rate} of the parameter of the distribution }
\item{rate<-}{\code{signature(object = "Exp")}: modifies the slot \code{rate} of the parameter of the distribution }

\item{rate}{\code{signature(object = "Contsimulation")}: returns the contamination rate }
\item{rate<-}{\code{signature(object = "Contsimulation")}: modifies the contamination rate }
}}
\keyword{}

\eof
\name{result-methods}
\docType{methods}
\alias{result-methods}
\alias{result}
\alias{result,Evaluation-method}
\title{ Methods for Function result in Package `distr'}
\description{result-methods}

\section{Methods}{\describe{
\item{result}{\code{signature(object = "Evaluation")}: returns the result of an evaluation}
}}
\keyword{}

\eof
\name{runs-methods}
\docType{methods}
\alias{runs-methods}
\alias{runs<--methods}
\alias{runs}
\alias{runs<-}
\alias{runs,Dataclass-method}
\alias{runs<-,Simulation-method}
\alias{runs<-,Contsimulation-method}
\title{ Methods for Function runs in Package `distr'}
\description{runs-methods}

\section{Methods}{\describe{

\item{runs}{\code{signature(object = "Dataclass")}: returns the number of runs }
\item{runs<-}{\code{signature(object = "Simulation")}: changes the number of runs }
\item{runs<-}{\code{signature(object = "Contsimulation")}: changes the number of runs }
}}
\keyword{}

\eof
\name{samplesize-methods}
\docType{methods}
\alias{samplesize-methods}
\alias{samplesize<--methods}
\alias{samplesize}
\alias{samplesize<-}
\alias{samplesize,Dataclass-method}
\alias{samplesize<-,Simulation-method}
\alias{samplesize<-,Contsimulation-method}
\title{ Methods for Function samplesize in Package `distr'}
\description{samplesize-methods}

\section{Methods}{\describe{

\item{samplesize}{\code{signature(object = "Dataclass")}: returns the size of the sample }
\item{samplesize<-}{\code{signature(object = "Simulation")}: changes the size of the sample }
\item{samplesize<-}{\code{signature(object = "Contsimulation")}: changes the size of the sample }
}}
\keyword{}

\eof
\name{savedata-methods}
\docType{methods}
\alias{savedata-methods}
\alias{savedata}
\alias{savedata,Dataclass-method}
\alias{savedata,Simulation-method}
\alias{savedata,Contsimulation-method}
\alias{savedata,Evaluation-method}
\title{ Methods for Function savedata in Package `distr' }
\description{savedata-methods}

\section{Methods}{\describe{

\item{savedata}{\code{signature(object = "Dataclass")}: saves the object (with the data) in the directory of R }

\item{savedata}{\code{signature(object = "Simulation")}: saves the object without the data in the directory of R
    (After loading the data can be reproduced by using simulate.) }

\item{savedata}{\code{signature(object = "Contsimulation")}: saves the object without the data in the directory of R
    (After loading the data can be reproduced by using simulate.) }

\item{savedata}{\code{signature(object = "Evaluation")}: saves the object in two files in the directory of R - one with data, 
one without as comment file }
}}
\seealso{
\code{\link{Dataclass-class}}
\code{\link{Simulation-class}}
\code{\link{Contsimulation-class}}
\code{\link{Evaluation-class}}
}
\keyword{}

\eof
\name{scale-methods}
\docType{methods}
\alias{scale-methods}
\alias{scale<--methods}
\alias{scale}
\alias{scale<-}
\alias{scale,GammaParameter-method}
\alias{scale,Gamma-method}
\alias{scale,LogisParameter-method}
\alias{scale,Logis-method}
\alias{scale,WeibullParameter-method}
\alias{scale,Weibull-method}
\alias{scale,CauchyParameter-method}
\alias{scale,Cauchy-method}
\alias{scale<-,GammaParameter-method}
\alias{scale<-,Gamma-method}
\alias{scale<-,LogisParameter-method}
\alias{scale<-,Logis-method}
\alias{scale<-,WeibullParameter-method}
\alias{scale<-,Weibull-method}
\alias{scale<-,CauchyParameter-method}
\alias{scale<-,Cauchy-method}
\title{ Methods for Function scale in Package `distr' }
\description{scale-methods}

\section{Methods}{\describe{

\item{scale}{\code{signature(object = "GammaParameter")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "GammaParameter")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "Gamma")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "Gamma")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "LogisParameter")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "LogisParameter")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "Logis")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "Logis")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "WeibullParameter")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "WeibullParameter")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "Weibull")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "Weibull")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "CauchyParameter")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "CauchyParameter")}: modifies the slot \code{scale} of the parameter of the distribution }

\item{scale}{\code{signature(object = "Cauchy")}: returns the slot \code{scale} of the parameter of the distribution }
\item{scale<-}{\code{signature(object = "Cauchy")}: modifies the slot \code{scale} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{sd-methods}
\docType{methods}
\alias{sd-methods}
\alias{sd<--methods}
\alias{sd}
\alias{sd<-}
\alias{sd,NormParameter-method}
\alias{sd,Norm-method}
\alias{sd<-,NormParameter-method}
\alias{sd<-,Norm-method}
\title{ Methods for Function sd in Package `distr' }
\description{sd-methods}
\section{Methods}{\describe{
\item{sd}{\code{signature(object = "NormParameter")}: returns the slot sd of the parameter of the distribution }    
\item{sd<-}{\code{signature(object = "NormParameter")}: modifies the slot sd of the parameter of the distribution }
\item{sd}{\code{signature(object = "Norm")}: returns the slot sd of the parameter of the distribution }
\item{sd<-}{\code{signature(object = "Norm")}: modifies the slot sd of the parameter of the distribution }
}}
\keyword{}

\eof
\name{sdlog-methods}
\docType{methods}
\alias{sdlog-methods}
\alias{sdlog<--methods}
\alias{sdlog}
\alias{sdlog<-}
\alias{sdlog,LnormParameter-method}
\alias{sdlog,Lnorm-method}
\alias{sdlog<-,LnormParameter-method}
\alias{sdlog<-,Lnorm-method}
\title{ Methods for Function sdlog in Package `distr' }
\description{}
\section{Methods}{\describe{

\item{sdlog}{\code{signature(object = "LnormParameter")}: returns the slot \code{sdlog} of the parameter of the distribution }
\item{sdlog<-}{\code{signature(object = "LnormParameter")}: modifies the slot \code{sdlog} of the parameter of the distribution }

\item{sdlog}{\code{signature(object = "Lnorm")}: returns the slot \code{sdlog} of the parameter of the distribution }
\item{sdlog<-}{\code{signature(object = "Lnorm")}: modifies the slot \code{sdlog} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{seed-methods}
\docType{methods}
\alias{seed-methods}
\alias{seed<--methods}
\alias{seed}
\alias{seed<-}
\alias{seed,Simulation-method}
\alias{seed<-,Simulation-method}
\alias{seed,Contsimulation-method}
\alias{seed<-,Contsimulation-method}
\title{ Methods for Function seed in Package `distr' }
\description{seed-methods}

\section{Methods}{\describe{

\item{seed}{\code{signature(object = "Simulation")}: returns the slot \code{seed} of an object of class \code{"Simulation"}}
\item{seed<-}{\code{signature(object = "Simulation")}: changes the slot \code{seed} of an object of class \code{"Simulation"}}

\item{seed}{\code{signature(object = "Contsimulation")}: returns the slot \code{seed} of an object of class \code{"Contsimulation"} }
\item{seed<-}{\code{signature(object = "Contsimulation")}: changes the slot \code{seed} of an object of class \code{"Contsimulation"} }
}}
\note{The value to which the seed is set has to be consistent with the \pkg{setRNG}-package;
to draw a ``new'' simulation, use something like \code{seed(X)<-setRNG();simulate(X)}; 
cf. manual to this package, p.~9}
\keyword{}

\eof
\name{shape-methods}
\docType{methods}
\alias{shape-methods}
\alias{shape<--methods}
\alias{shape}
\alias{shape<-}
\alias{shape,GammaParameter-method}
\alias{shape,Gamma-method}
\alias{shape,WeibullParameter-method}
\alias{shape,Weibull-method}
\alias{shape<-,GammaParameter-method}
\alias{shape<-,Gamma-method}
\alias{shape<-,WeibullParameter-method}
\alias{shape<-,Weibull-method}
\title{ Methods for Function shape in Package `distr' }
\description{shape-methods}

\section{Methods}{\describe{

\item{shape}{\code{signature(object  = "GammaParameter")}: returns the slot \code{shape} of a parameter of a Gamma distribution }
\item{shape<-}{\code{signature(object = "GammaParameter")}: modifies the slot \code{shape} of a parameter of a Gamma distribution }

\item{shape}{\code{signature(object = "Gamma")}: returns the slot \code{shape} of the parameter slot of a Gamma distribution }
\item{shape<-}{\code{signature(object = "Gamma")}: modifies the slot shape of the parameter slot of a Gamma distribution }

\item{shape}{\code{signature(object  = "WeibullParameter")}: returns the slot \code{shape} of a parameter of a Weibull distribution }
\item{shape<-}{\code{signature(object = "WeibullParameter")}: modifies the slot \code{shape} of a parameter of a Weibull distribution }

\item{shape}{\code{signature(object  = "Weibull")}: returns the slot \code{shape} of the parameter slot of the distribution }
\item{shape<-}{\code{signature(object = "Weibull")}: modifies the slot \code{shape} of the parameter slot of the distribution }
}}
\keyword{}

\eof
\name{shape1-methods}
\docType{methods}
\alias{shape1-methods}
\alias{shape1<--methods}
\alias{shape1}
\alias{shape1<-}
\alias{shape1,BetaParameter-method}
\alias{shape1,Beta-method}
\alias{shape1<-,BetaParameter-method}
\alias{shape1<-,Beta-method}
\title{ Methods for Function shape1 in Package `distr' }
\description{shape-methods}

\section{Methods}{\describe{

\item{shape1}{\code{signature(object = "BetaParameter")}: returns the slot \code{shape1} of the parameter of the distribution }
\item{shape1<-}{\code{signature(object = "BetaParameter")}: modifies the slot \code{shape1} of the parameter of the distribution }

\item{shape1}{\code{signature(object = "Beta")}: returns the slot \code{shape1} of the parameter of the distribution }
\item{shape1<-}{\code{signature(object = "Beta")}: modifies the slot \code{shape1} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{shape2-methods}
\docType{methods}
\alias{shape2-methods}
\alias{shape2<--methods}
\alias{shape2}
\alias{shape2<-}
\alias{shape2,BetaParameter-method}
\alias{shape2,Beta-method}
\alias{shape2<-,BetaParameter-method}
\alias{shape2<-,Beta-method}
\title{ Methods for Function shape2 in Package `distr' }
\description{shape-methods}
\section{Methods}{\describe{
\item{shape2}{\code{signature(object = "BetaParameter")}: returns the slot shape2 of the parameter of the distribution }
\item{shape2<-}{\code{signature(object = "BetaParameter")}: modifies the slot shape2 of the parameter of the distribution }
\item{shape2}{\code{signature(object = "Beta")}: returns the slot shape2 of the parameter of the distribution }
\item{shape2<-}{\code{signature(object = "Beta")}: modifies the slot shape2 of the parameter of the distribution }
}}
\keyword{}

\eof
\name{simplifyr-methods}
\docType{methods}
\alias{simplifyr-methods}
\alias{simplifyr}
\alias{simplifyr,UnivariateDistribution-method}
\title{ Methods for Function simplifyr in Package `distr'}
\description{simplifyr-methods}

\section{Methods}{\describe{

\item{simplifyr}{\code{signature(.Object = "UnivariateDistribution")}: After several transformations of a given distribution it may take quite 
a long time  to generate random numbers from the resulting distribution. simplifyr generates a certain number, 
by default \eqn{10^5}, of random numbers once. This pool of random numbers forms the basis for further uses of the 
r-method. That is, random numbers are generated by sampling with replacement out of this pool. }
}}
\note{ If you want to generate many random numbers, you should use simplifyr with a big size to be sure,
that your numbers are really random. }

\seealso{
\code{\link{Distribution-class}}
}

\examples{
F <- ( Norm() + Binom() + Pois() + Exp() ) * 2 - 10
system.time(r(F)(10^6))
simplifyr(F, size = 10^6)
system.time(r(F)(10^6))}

\keyword{}

\eof
\name{simulate-methods}
\docType{methods}
\alias{simulate-methods}
\alias{simulate}
\alias{simulate,Simulation-method}
\alias{simulate,Contsimulation-method}
\title{ Methods for Function simulate in Package `distr' }
\description{simulate-methods}

\section{Methods}{\describe{

\item{simulate}{\code{signature(x = "Simulation")}: generates the random numbers for the simulation }

\item{simulate}{\code{signature(x = "Contsimulation")}: generates the random numbers for the simulation }

}}
\keyword{}

\eof
\name{size-methods}
\docType{methods}
\alias{size-methods}
\alias{size<--methods}
\alias{size}
\alias{size<-}
\alias{size,BinomParameter-method}
\alias{size,Binom-method}
\alias{size,NbinomParameter-method}
\alias{size,Nbinom-method}
\alias{size<-,BinomParameter-method}
\alias{size<-,Binom-method}
\alias{size<-,NbinomParameter-method}
\alias{size<-,Nbinom-method}
\title{ Methods for Function size in Package `distr' }
\description{size-methods}

\section{Methods}{\describe{

\item{size}{\code{signature(object  = "BinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "BinomParameter")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "Binom")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "Binom")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "NbinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "NbinomParameter")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "Nbinom")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "Nbinom")}: modifies the slot \code{size} of the parameter of the distribution }
}}
\keyword{}

\eof
\name{standardMethods}
\alias{standardMethods}
\title{standardMethods}
\description{
Creates definitions for accessor and replacement functions of an given class.
}
\usage{
standardMethods(class, writetofile = FALSE, directory)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{class}{the class for which accessor and replacement functions
    are to be produced, given as a string}
  \item{writetofile}{logical value, indicating wheter output is to be written to a file}
  \item{directory}{if writetofile = TRUE, the output is
    written to a file in the given directory, the name of the file
    starting with "classname " and ending with "StandardMethods.txt"}
}
\value{no value is returned
}
\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de}}
\examples{
setClass("testclass", representation(a = "numeric", b = "character"))
standardMethods("testclass")
#directory = "C:/Dokumente und Einstellungen/X/Eigene Dateien/Studium/R/SWP/"
#standardMethods("testclass", writetofile = TRUE, directory = directory)
}
\keyword{}

\eof
\name{summary-methods}
\docType{methods}
\alias{summary-methods}
\alias{summary,Dataclass-method}
\alias{summary,Simulation-method}
\alias{summary,Contsimulation-method}
\alias{summary,Evaluation-method}
\title{ Methods for Function summary in Package `distr' }
\description{summary-methods}

\section{Methods}{\describe{


\item{summary}{\code{signature(object = "Dataclass")}: returns the same information as print, moreover a statistical summary for 
each run }

\item{summary}{\code{signature(object = "Simulation")}: returns filename, seed, number of runs, the size of the sample and a
statistical summary for each run }

\item{summary}{\code{signature(object = "Contsimulation")}: returns filename, seed, number of runs, the size of the sample, the
rate and a statistical summary for each run of the real data }

\item{summary}{\code{signature(object = "Evaluation")}: returns the name of the data object, its filename, the estimator used and
a statistical summary of the result }

}}
\keyword{}

\eof
\name{support-methods}
\docType{methods}
\alias{support-methods}
\alias{support}
\alias{support,DiscreteDistribution-method}
\title{ Methods for Function support in Package `distr'}
\description{support-methods}

\section{Methods}{\describe{

\item{support}{\code{signature(object =
    "DiscreteDistributionContsimulation")}: returns the support}
}}
\keyword{}

\eof
\name{vectororNULL-class}
\docType{class}
\alias{vectororNULL-class}

\title{Class "vectororNULL" }
\description{ auxiliary class; may contain either a vector or NULL, cf. J. Chambers, "green book".}
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
No methods defined with class "vectororNULL" in the signature.
}
\author{Thomas Stabla \email{Thomas.Stabla@uni-bayreuth.de},\cr Florian Camphausen \email{Florian.Camphausen@uni-bayreuth.de},\cr
 Peter Ruckdeschel \email{Peter.Ruckdeschel@uni-bayreuth.de},\cr Matthias Kohl \email{Matthias.Kohl@uni-bayreuth.de}}
\note{ Dataclass-class can save data either of type "NULL" (means no data) or "vector"}
\code{\link{Dataclass-class}}
\keyword{}

\eof
